@@ -37,7 +37,7 @@
 #include "ao_markword.h"
 #include "ao_tasks.h"
 #include "ao_xmltagging.h"
-
+#include "ao_wrapwords.h"
 
 
 GeanyPlugin		*geany_plugin;
@@ -77,6 +77,8 @@ typedef struct
 	gboolean enable_bookmarklist;
 	gboolean enable_markword;
 	gboolean enable_xmltagging;
+	gboolean enable_enclose_words;
+	gboolean enable_enclose_words_auto;
 	gboolean strip_trailing_blank_lines;
 
 	gchar *tasks_token_list;
@@ -271,6 +273,10 @@ void plugin_init(GeanyData *data)
 		"addons", "strip_trailing_blank_lines", FALSE);
 	ao_info->enable_xmltagging = utils_get_setting_boolean(config, "addons",
 		"enable_xmltagging", FALSE);
+	ao_info->enable_enclose_words = utils_get_setting_boolean(config, "addons",
+		"enable_enclose_words", FALSE);
+	ao_info->enable_enclose_words_auto = utils_get_setting_boolean(config, "addons",
+		"enable_enclose_words_auto", FALSE);
 
 	plugin_module_make_resident(geany_plugin);
 
@@ -285,7 +291,7 @@ void plugin_init(GeanyData *data)
 	ao_blanklines_set_enable(ao_info->strip_trailing_blank_lines);
 
 	/* setup keybindings */
-	key_group = plugin_set_key_group(geany_plugin, "addons", KB_COUNT, NULL);
+	key_group = plugin_set_key_group(geany_plugin, "addons", KB_COUNT+8, NULL);
 	keybindings_set_item(key_group, KB_FOCUS_BOOKMARK_LIST, kb_bmlist_activate,
 		0, 0, "focus_bookmark_list", _("Focus Bookmark List"), NULL);
 	keybindings_set_item(key_group, KB_FOCUS_TASKS, kb_tasks_activate,
@@ -295,6 +301,9 @@ void plugin_init(GeanyData *data)
 	keybindings_set_item(key_group, KB_XMLTAGGING, kb_ao_xmltagging,
 		0, 0, "xml_tagging", _("Run XML tagging"), NULL);
 
+	ao_enclose_words_init(ao_info->config_file, key_group);
+	ao_enclose_words_set_enabled (ao_info->enable_enclose_words, ao_info->enable_enclose_words_auto);
+
 	g_key_file_free(config);
 }
 
@@ -359,6 +368,12 @@ static void ao_configure_response_cb(GtkDialog *dialog, gint response, gpointer
 			g_object_get_data(G_OBJECT(dialog), "check_blanklines"))));
 		ao_info->enable_xmltagging = (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(
 			g_object_get_data(G_OBJECT(dialog), "check_xmltagging"))));
+		ao_info->enable_enclose_words = (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(
+			g_object_get_data(G_OBJECT(dialog), "check_enclose_words"))));
+		ao_info->enable_enclose_words_auto = (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(
+			g_object_get_data(G_OBJECT(dialog), "check_enclose_words_auto"))));
+
+		ao_enclose_words_set_enabled (ao_info->enable_enclose_words, ao_info->enable_enclose_words_auto);
 
 		g_key_file_load_from_file(config, ao_info->config_file, G_KEY_FILE_NONE, NULL);
 		g_key_file_set_boolean(config, "addons",
@@ -377,6 +392,10 @@ static void ao_configure_response_cb(GtkDialog *dialog, gint response, gpointer
 		  ao_info->strip_trailing_blank_lines);
 		g_key_file_set_boolean(config, "addons", "enable_xmltagging",
 			ao_info->enable_xmltagging);
+		g_key_file_set_boolean(config, "addons", "enable_enclose_words",
+			ao_info->enable_enclose_words);
+		g_key_file_set_boolean(config, "addons", "enable_enclose_words_auto",
+			ao_info->enable_enclose_words_auto);
 
 		g_object_set(ao_info->doclist, "enable-doclist", ao_info->enable_doclist, NULL);
 		g_object_set(ao_info->doclist, "sort-mode", ao_info->doclist_sort_mode, NULL);
@@ -418,6 +437,7 @@ GtkWidget *plugin_configure(GtkDialog *dialog)
 	GtkWidget *check_bookmarklist, *check_markword, *frame_tasks, *vbox_tasks;
 	GtkWidget *check_tasks_scan_mode, *entry_tasks_tokens, *label_tasks_tokens, *tokens_hbox;
 	GtkWidget *check_blanklines, *check_xmltagging;
+	GtkWidget *check_enclose_words, *check_enclose_words_auto, *enclose_words_config_button, *enclose_words_hbox;
 
 	vbox = gtk_vbox_new(FALSE, 6);
 
@@ -465,8 +485,7 @@ GtkWidget *plugin_configure(GtkDialog *dialog)
 	gtk_box_pack_start(GTK_BOX(vbox), frame_doclist, FALSE, FALSE, 3);
 
 	check_openuri = gtk_check_button_new_with_label(
-		/* TODO fix the string */
-		_("Show a 'Open URI' menu item in the editor menu"));
+		_("Show an 'Open URI' item in the editor menu"));
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check_openuri),
 		ao_info->enable_openuri);
 	gtk_box_pack_start(GTK_BOX(vbox), check_openuri, FALSE, FALSE, 3);
@@ -537,6 +556,25 @@ GtkWidget *plugin_configure(GtkDialog *dialog)
 		ao_info->enable_xmltagging);
 	gtk_box_pack_start(GTK_BOX(vbox), check_xmltagging, FALSE, FALSE, 3);
 
+	check_enclose_words = gtk_check_button_new_with_label(
+		_("Enclose selection on configurable keybindings"));
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check_enclose_words),
+		ao_info->enable_enclose_words);
+
+	enclose_words_config_button = gtk_button_new_with_label ("Configure enclose pairs");
+	g_signal_connect(enclose_words_config_button, "clicked", G_CALLBACK(ao_enclose_words_config), dialog);
+	enclose_words_hbox = gtk_hbox_new(FALSE, 0);
+	gtk_box_pack_start(GTK_BOX(enclose_words_hbox), check_enclose_words, FALSE, FALSE, 3);
+	gtk_box_pack_start(GTK_BOX(enclose_words_hbox), enclose_words_config_button, TRUE, TRUE, 3);
+	gtk_box_pack_start(GTK_BOX(vbox), enclose_words_hbox, FALSE, FALSE, 3);
+
+	check_enclose_words_auto = gtk_check_button_new_with_label(
+		_("Enclose selection automatically (without having to press a keybinding)"));
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check_enclose_words_auto),
+		ao_info->enable_enclose_words_auto);
+	gtk_box_pack_start(GTK_BOX(vbox), check_enclose_words_auto, FALSE, FALSE, 3);
+
+
 	g_object_set_data(G_OBJECT(dialog), "check_doclist", check_doclist);
 	g_object_set_data(G_OBJECT(dialog), "radio_doclist_name", radio_doclist_name);
 	g_object_set_data(G_OBJECT(dialog), "radio_doclist_tab_order", radio_doclist_tab_order);
@@ -551,6 +589,9 @@ GtkWidget *plugin_configure(GtkDialog *dialog)
 	g_object_set_data(G_OBJECT(dialog), "check_markword", check_markword);
 	g_object_set_data(G_OBJECT(dialog), "check_blanklines", check_blanklines);
 	g_object_set_data(G_OBJECT(dialog), "check_xmltagging", check_xmltagging);
+	g_object_set_data(G_OBJECT(dialog), "check_enclose_words", check_enclose_words);
+	g_object_set_data(G_OBJECT(dialog), "check_enclose_words_auto", check_enclose_words_auto);
+	g_object_set_data(G_OBJECT(dialog), "enclose_words_config_button", enclose_words_config_button);
 	g_signal_connect(dialog, "response", G_CALLBACK(ao_configure_response_cb), NULL);
 
 	ao_configure_tasks_toggled_cb(GTK_TOGGLE_BUTTON(check_tasks), dialog);
@@ -581,3 +622,4 @@ void plugin_cleanup(void)
 	g_free(ao_info->config_file);
 	g_free(ao_info);
 }
+
