@@ -19,7 +19,11 @@
  *	  MA 02110-1301, USA.
  */
 
-#include "geanyplugin.h"
+#ifdef HAVE_CONFIG_H
+	#include "config.h"
+#endif
+#include <geanyplugin.h>
+
 #include "addons.h"
 #include "ao_xmltagging.h"
 
@@ -88,7 +92,7 @@ void ao_xmltagging(void)
 			tag = g_strdup(gtk_entry_get_text(GTK_ENTRY(textbox)));
 			if (NZV(tag))
 			{
-				gint end = 0;
+				gsize end = 0;
 				GString *tmp = NULL;
 				const gchar *end_tag;
 
