@@ -45,10 +45,12 @@
 #include "tabs.h"
 #include "pixbuf.h"
 
+#include "cell_renderers/cellrendererbreakicon.h"
+#include "cell_renderers/cellrenderertoggle.h"
+
 /* Tree view columns */
 enum
 {
-   ICON,
    FILEPATH,
    CONDITION,
    HITSCOUNT,
@@ -64,7 +66,6 @@ static GtkTreeModel		*model = NULL;
 static GtkTreeStore		*store = NULL;
 
 /* column cell renderes */
-static GtkCellRenderer	*enable_renderer;
 static GtkCellRenderer	*hcount_renderer;
 static GtkCellRenderer	*condition_renderer;
 
@@ -80,10 +81,9 @@ move_to_line_cb on_break_clicked = NULL;
 /* 
  * gets tree row reference for an unsected row at the same depth
  */
-GtkTreeRowReference* get_unselected_sibling(GtkTreePath *path)
+static GtkTreeRowReference* get_unselected_sibling(GtkTreePath *path)
 {
 	GtkTreeRowReference *sibling = NULL;
-	
 	GtkTreeSelection *selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(tree));
 
 	/* move down find first unselected sibling */
@@ -149,34 +149,104 @@ static void update_file_node(GtkTreeIter *file_iter)
 }
 
 /* 
- * GtkTreeView cell renderer functions that do not render and make ineditable file rows
+ * shows a tooltip for a file name
  */
-void on_render(GtkTreeViewColumn *tree_column, GtkCellRenderer *cell, GtkTreeModel *tree_model,
+static gboolean on_query_tooltip(GtkWidget *widget, gint x, gint y, gboolean keyboard_mode, GtkTooltip *tooltip, gpointer user_data)
+{
+	gboolean show = FALSE;
+	int bx, by;
+	GtkTreePath *tpath = NULL;
+	GtkTreeViewColumn *column = NULL;
+
+	gtk_tree_view_convert_widget_to_bin_window_coords(GTK_TREE_VIEW(widget), x, y, &bx, &by);
+	if (gtk_tree_view_get_path_at_pos(GTK_TREE_VIEW(widget), bx, by, &tpath, &column, NULL, NULL))
+	{
+		if (1 == gtk_tree_path_get_depth(tpath) && column == gtk_tree_view_get_column(GTK_TREE_VIEW(widget), FILEPATH))
+		{
+			GtkTreeIter iter;
+			gchar *path = NULL;
+			
+			gtk_tree_model_get_iter(model, &iter, tpath);
+			gtk_tree_model_get(model, &iter, FILEPATH, &path, -1);
+
+			gtk_tooltip_set_text(tooltip, path);
+			
+			gtk_tree_view_set_tooltip_row(GTK_TREE_VIEW(widget), tooltip, tpath);
+
+			show = TRUE;
+		}
+		gtk_tree_path_free(tpath);
+	}
+	
+	return show;
+}
+
+/* 
+ * shows only the file name instead of a full path
+ */
+static void on_render_filename(GtkTreeViewColumn *tree_column, GtkCellRenderer *cell, GtkTreeModel *tree_model,
 	GtkTreeIter *iter, gpointer data)
 {
-	GtkTreePath *path = gtk_tree_model_get_path(model, iter);
-	if (data)
+	gchar *path = NULL;
+	GtkTreePath *tpath;
+
+	gtk_tree_model_get(model, iter, FILEPATH, &path, -1);
+
+	tpath = gtk_tree_model_get_path(model, iter);
+	if (1 != gtk_tree_path_get_depth(tpath))
 	{
-		if (gtk_tree_path_get_depth(path) == 1)
-		{
-			g_object_set(cell, "text", "", NULL);
-			g_object_set(cell, "editable", FALSE, NULL);
-		}
-		else
-		{
-			g_object_set(cell, "editable", TRUE, NULL);
-		}
+		g_object_set(cell, "text", path, NULL);
 	}
 	else
 	{
-		if (gtk_tree_path_get_depth(path) == 1)
-		{
-			g_object_set(cell, "visible", FALSE, NULL);
-		}
-		else
-		{
-			g_object_set(cell, "visible", TRUE, NULL);
-		}
+		gchar *name = g_path_get_basename(path);
+		g_object_set(cell, "text", name ? name : path, NULL);
+		g_free(name);
+	}
+	
+	if (path)
+	{
+		g_free(path);
+	}
+}
+
+/* 
+ * hides file checkbox for breaks rows
+ */
+static void on_render_enable_for_file(GtkTreeViewColumn *tree_column, GtkCellRenderer *cell, GtkTreeModel *tree_model,
+	GtkTreeIter *iter, gpointer data)
+{
+	GtkTreePath *path = gtk_tree_model_get_path(model, iter);
+	g_object_set(cell, "visible", 1 == gtk_tree_path_get_depth(path), NULL);
+	gtk_tree_path_free(path);
+}
+
+/* 
+ * hides break pixbuf for file rows
+ */
+static void on_render_enable_break(GtkTreeViewColumn *tree_column, GtkCellRenderer *cell, GtkTreeModel *tree_model,
+	GtkTreeIter *iter, gpointer data)
+{
+	GtkTreePath *path = gtk_tree_model_get_path(model, iter);
+	g_object_set(cell, "visible", 1 != gtk_tree_path_get_depth(path), NULL);
+	gtk_tree_path_free(path);
+}
+
+/* 
+ * makes condition and hitscount uneditable and empty for file rows
+ */
+static void on_render(GtkTreeViewColumn *tree_column, GtkCellRenderer *cell, GtkTreeModel *tree_model,
+	GtkTreeIter *iter, gpointer data)
+{
+	GtkTreePath *path = gtk_tree_model_get_path(model, iter);
+	if (gtk_tree_path_get_depth(path) == 1)
+	{
+		g_object_set(cell, "text", "", NULL);
+		g_object_set(cell, "editable", FALSE, NULL);
+	}
+	else
+	{
+		g_object_set(cell, "editable", TRUE, NULL);
 	}
 	gtk_tree_path_free(path);
 }
@@ -190,21 +260,20 @@ void on_render(GtkTreeViewColumn *tree_column, GtkCellRenderer *cell, GtkTreeMod
  */
 static void on_row_double_click(GtkTreeView *tree_view, GtkTreePath *path, GtkTreeViewColumn *column, gpointer user_data)
 {
+	GtkTreeIter iter, parent_iter;
+	gchar *file;
+	int line;
+	
 	if (1 == gtk_tree_path_get_depth(path))
 	{
 		return;
 	}
 	
-	GtkTreeIter iter;
 	gtk_tree_model_get_iter (
 		 model,
 		 &iter,
 		 path);
-    
-    gchar *file;
-	int line;
 	
-	GtkTreeIter parent_iter;
 	gtk_tree_model_iter_parent(model, &parent_iter, &iter);
 	
 	gtk_tree_model_get (
@@ -228,28 +297,27 @@ static void on_row_double_click(GtkTreeView *tree_view, GtkTreePath *path, GtkTr
 /*
  * editing "condition" column value finished
  */
-void on_condition_changed(GtkCellRendererText *renderer, gchar *path, gchar *new_text, gpointer user_data)
+static void on_condition_changed(GtkCellRendererText *renderer, gchar *path, gchar *new_text, gpointer user_data)
 {
-	GtkTreeIter  iter;
-    GtkTreePath *tree_path = gtk_tree_path_new_from_string (path);
+	gchar *file;
+	int line;
+	gchar* oldcondition;
+	GtkTreeIter iter, parent_iter;
+	GtkTreePath *tree_path = gtk_tree_path_new_from_string (path);
 
 	gtk_tree_model_get_iter (
 		 model,
 		 &iter,
 		 tree_path);
 	
-	GtkTreeIter parent_iter;
 	gtk_tree_model_iter_parent(model, &parent_iter, &iter);
 
-	gchar *file;
 	gtk_tree_model_get (
 		model,
 		&parent_iter,
 		FILEPATH, &file,
 		-1);
 	
-	int line;
-	gchar* oldcondition;
 	gtk_tree_model_get (
 		model,
 		&iter,
@@ -268,32 +336,33 @@ void on_condition_changed(GtkCellRendererText *renderer, gchar *path, gchar *new
 /*
  * editing "hitscount" column value finished
  */
-void on_hitscount_changed(GtkCellRendererText *renderer, gchar *path, gchar *new_text, gpointer user_data)
+static void on_hitscount_changed(GtkCellRendererText *renderer, gchar *path, gchar *new_text, gpointer user_data)
 {
+	GtkTreeIter iter, parent_iter;
+	GtkTreePath *tree_path;
+	gchar *file;
+	int line;
+	gint oldcount;
 	int count = atoi(new_text);
+
 	if (!count && strcmp(new_text, "0"))
 		return;
 
-	GtkTreeIter  iter;
-    GtkTreePath *tree_path = gtk_tree_path_new_from_string (path);
+	tree_path = gtk_tree_path_new_from_string (path);
 
 	gtk_tree_model_get_iter (
 		 model,
 		 &iter,
 		 tree_path);
 
-	GtkTreeIter parent_iter;
 	gtk_tree_model_iter_parent(model, &parent_iter, &iter);
 
-	gchar *file;
 	gtk_tree_model_get (
 		model,
 		&parent_iter,
 		FILEPATH, &file,
 		-1);
 
-	int line;
-	gint oldcount;
 	gtk_tree_model_get (
 		model,
 		&iter,
@@ -309,23 +378,26 @@ void on_hitscount_changed(GtkCellRendererText *renderer, gchar *path, gchar *new
 }                                                        
 
 /*
- * "Enabled" checkbox has been clicked
+ * enable / disable all breaks for a file when it's checkbox icon has been clicked
  */
-void on_activeness_changed(GtkCellRendererToggle *cell_renderer, gchar *path, gpointer user_data)
+static void on_enable_for_file(GtkCellRendererToggle *cell_renderer, gchar *path, gpointer user_data)
 {
+	GtkTreeIter  iter;
+	GtkTreePath *tree_path;
+	gboolean current_state;
+
 	/* do not process event is page is readonly (debug is running) */
 	if (readonly)
 		return;
 	
-	GtkTreeIter  iter;
-    GtkTreePath *tree_path = gtk_tree_path_new_from_string (path);
+	tree_path = gtk_tree_path_new_from_string (path);
 	
 	gtk_tree_model_get_iter (
 		model,
 		&iter,
 		tree_path);
     
-	gboolean current_state = gtk_cell_renderer_toggle_get_active(cell_renderer);
+	current_state = gtk_cell_renderer_toggle_get_active(cell_renderer);
 
     /* check if this is a file row */
     if(1 == gtk_tree_path_get_depth(tree_path))
@@ -341,13 +413,37 @@ void on_activeness_changed(GtkCellRendererToggle *cell_renderer, gchar *path, gp
 
 		g_free(file);
 	}
-	else
-	{
-		GtkTreeIter parent_iter;
-		gtk_tree_model_iter_parent(model, &parent_iter, &iter);
 
+	gtk_tree_path_free(tree_path);
+}
+
+/*
+ * enable / disable particulary break when it's icon has been clicked
+ */
+static void on_enable_break(CellRendererBreakIcon *cell_renderer, gchar *path, gpointer user_data)
+{
+	GtkTreeIter  iter;
+	GtkTreePath *tree_path;
+	
+	/* do not process event is page is readonly (debug is running) */
+	if (readonly)
+		return;
+	
+	tree_path = gtk_tree_path_new_from_string (path);
+	
+	gtk_tree_model_get_iter (
+		model,
+		&iter,
+		tree_path);
+    
+    /* check if this is not a file row */
+    if(1 != gtk_tree_path_get_depth(tree_path))
+	{
 		gchar *file;
 		int line;
+		GtkTreeIter parent_iter;
+
+		gtk_tree_model_iter_parent(model, &parent_iter, &iter);
 
 		gtk_tree_model_get (
 			model,
@@ -373,24 +469,28 @@ void on_activeness_changed(GtkCellRendererToggle *cell_renderer, gchar *path, gp
  */
 static gboolean on_key_pressed(GtkWidget *widget, GdkEvent *event, gpointer user_data)
 {
+	guint keyval = ((GdkEventKey*)event)->keyval;
+	GtkTreeSelection *selection;
+	GList *rows;
+
 	/* do not process event is page is readonly (debug is running) */
 	if (readonly)
 		return FALSE;
 
-    guint keyval = ((GdkEventKey*)event)->keyval;
-
 	/* get selected rows */
-	GtkTreeSelection *selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(tree));
-	GList *rows = gtk_tree_selection_get_selected_rows(selection, &model);
+	selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(tree));
+	rows = gtk_tree_selection_get_selected_rows(selection, &model);
 	rows = g_list_sort(rows, (GCompareFunc)gtk_tree_path_compare);
 
 	if (keyval == GDK_Delete && rows && g_list_length(rows))
 	{
+		GList *breaks, *iter;
+		GtkTreeRowReference *new_selection = NULL;
+		GtkTreePath *first_path = (GtkTreePath*)rows->data;
+
 		/* "delete selected rows" */
 
 		/* get new selection */
-		GtkTreeRowReference *new_selection = NULL;
-		GtkTreePath *first_path = (GtkTreePath*)rows->data;
 		if (gtk_tree_path_get_depth(first_path) > 1)
 		{
 			new_selection = get_unselected_sibling(first_path);
@@ -408,13 +508,12 @@ static gboolean on_key_pressed(GtkWidget *widget, GdkEvent *event, gpointer user
 		
 		/* collect GList of breakpoints to remove
 		if file row is met - add all unselected breaks to the list as well */
-		GList *iter = rows;
-		GList *breaks = NULL;
-		while (iter)
+		breaks = NULL;
+		for (iter = rows; iter; iter = iter->next)
 		{
 			GtkTreePath *path = (GtkTreePath*)iter->data;
-			
 			GtkTreeIter titer;
+			
 			gtk_tree_model_get_iter(model, &titer, path);
 			
 			if (1 == gtk_tree_path_get_depth(path))
@@ -428,11 +527,12 @@ static gboolean on_key_pressed(GtkWidget *widget, GdkEvent *event, gpointer user
 					{
 						gchar *file = NULL;
 						gint line;
+						breakpoint *bp;
 
 						gtk_tree_model_get(model, &titer, FILEPATH, &file, -1);
 						gtk_tree_model_get(model, &citer, LINE, &line, -1);
 
-						breakpoint *bp = breaks_lookup_breakpoint(file, line);
+						bp = breaks_lookup_breakpoint(file, line);
 						
 						breaks = g_list_append(breaks, bp);
 						
@@ -444,21 +544,22 @@ static gboolean on_key_pressed(GtkWidget *widget, GdkEvent *event, gpointer user
 			else
 			{
 				GtkTreeIter piter;
+				gchar *file = NULL;
+				gint line;
+				breakpoint *bp;
+
 				gtk_tree_model_iter_parent(model, &piter, &titer);
 				
-				gchar *file = NULL;
 				gtk_tree_model_get(model, &piter, FILEPATH, &file, -1);
 
-				gint line;
 				gtk_tree_model_get(model, &titer, LINE, &line, -1);
 
-				breakpoint *bp = breaks_lookup_breakpoint(file, line);
+				bp = breaks_lookup_breakpoint(file, line);
 				
 				breaks = g_list_append(breaks, bp);
 				
 				g_free(file);
 			}
-			iter = iter->next;
 		}
 		
 		if (1 == g_list_length(breaks))
@@ -493,30 +594,6 @@ static gboolean on_key_pressed(GtkWidget *widget, GdkEvent *event, gpointer user
 	return FALSE;
 }
 
-/*
- * update existing breakpoint icon
- * arguments:
- * 		bp - breakpoint to update
- */
-void bptree_update_break_icon(breakpoint* bp)
-{
-	GdkPixbuf *pixbuf;
-	if (!bp->enabled)
-	{
-		pixbuf = break_disabled_pixbuf;
-	}
-	else if (bp->hitscount || strlen(bp->condition))
-	{
-		pixbuf = break_condition_pixbuf;
-	}
-	else
-	{
-		pixbuf = break_pixbuf;
-	}
-
-	gtk_tree_store_set (store, &bp->iter, ICON, pixbuf, -1);
-}
-
 /*
  * Interface functions
  */
@@ -528,6 +605,10 @@ void bptree_update_break_icon(breakpoint* bp)
  */
 gboolean bptree_init(move_to_line_cb cb)
 {
+	GtkTreeSelection *selection;
+	GtkTreeViewColumn *column;
+	GtkCellRenderer *renderer;
+
 	/* save double click callback */
 	on_break_clicked = cb;
 	
@@ -542,7 +623,6 @@ gboolean bptree_init(move_to_line_cb cb)
 	/* create tree view */
 	store = gtk_tree_store_new (
 		N_COLUMNS,
-		GDK_TYPE_PIXBUF,
 		G_TYPE_STRING,
 		G_TYPE_STRING,
 		G_TYPE_INT,
@@ -551,31 +631,49 @@ gboolean bptree_init(move_to_line_cb cb)
 		G_TYPE_STRING);
 	model = GTK_TREE_MODEL(store);
 	tree = gtk_tree_view_new_with_model (model);
+	g_object_unref(store);
 	
 	/* set tree view properties */
 	gtk_tree_view_set_headers_visible(GTK_TREE_VIEW(tree), 1);
+	gtk_widget_set_has_tooltip(GTK_WIDGET(tree), TRUE);
 	/* multiple selection */
-	GtkTreeSelection *selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(tree));
+	selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(tree));
 	gtk_tree_selection_set_mode(selection, GTK_SELECTION_MULTIPLE);
 	
 	/* connect signals */
 	g_signal_connect(G_OBJECT(tree), "key-press-event", G_CALLBACK (on_key_pressed), NULL);
 	g_signal_connect(G_OBJECT(tree), "row-activated", G_CALLBACK (on_row_double_click), NULL);
+	g_signal_connect(G_OBJECT(tree), "query-tooltip", G_CALLBACK (on_query_tooltip), NULL);
 
 	/* creating columns */
-	GtkTreeViewColumn	*column;
 
 	/* icon, file */
-	GtkCellRenderer *renderer = gtk_cell_renderer_text_new ();
+	renderer = gtk_cell_renderer_text_new ();
 	column = gtk_tree_view_column_new();
 	gtk_tree_view_column_pack_end(column, renderer, TRUE);
-	gtk_tree_view_column_set_attributes(column, renderer, "text", FILEPATH, NULL);	
-	GtkCellRenderer *icon_renderer = gtk_cell_renderer_pixbuf_new ();
-	g_object_set(icon_renderer, "follow-state", TRUE, NULL);
-	gtk_tree_view_column_pack_end(column, icon_renderer, FALSE);
-	gtk_tree_view_column_set_attributes(column, icon_renderer, "pixbuf", ICON, NULL);	
+	gtk_tree_view_column_set_cell_data_func(column, renderer, on_render_filename, NULL, NULL);
+
+	/* enable for file */
+	renderer = cell_renderer_toggle_new ();
+	g_signal_connect (G_OBJECT(renderer), "toggled", G_CALLBACK(on_enable_for_file), NULL);
+	gtk_tree_view_column_pack_end(column, renderer, FALSE);
+	gtk_tree_view_column_set_attributes(column, renderer, "active", ENABLED, NULL);
+	gtk_tree_view_column_set_cell_data_func(column, renderer, on_render_enable_for_file, NULL, NULL);
+
+	/* enable breakpoint */
+	renderer = cell_renderer_break_icon_new ();
+	g_signal_connect (G_OBJECT(renderer), "clicked", G_CALLBACK(on_enable_break), NULL);
+
+	g_object_set(renderer, "pixbuf_enabled", (gpointer)break_pixbuf, NULL);
+	g_object_set(renderer, "pixbuf_disabled", (gpointer)break_disabled_pixbuf, NULL);
+	g_object_set(renderer, "pixbuf_conditional", (gpointer)break_condition_pixbuf, NULL);
+	g_object_set(renderer, "pixbuf_file", (gpointer)break_pixbuf, NULL);
+	
+	gtk_tree_view_column_pack_end(column, renderer, FALSE);
+	gtk_tree_view_column_set_attributes(column, renderer, "enabled", ENABLED, "condition", CONDITION, "hitscount", HITSCOUNT, NULL);
+	gtk_tree_view_column_set_cell_data_func(column, renderer, on_render_enable_break, NULL, NULL);
+
 	gtk_tree_view_column_set_title(column, _("Location"));
-	gtk_tree_view_column_set_cell_data_func(column, icon_renderer, on_render, NULL, NULL);
 	gtk_tree_view_column_set_resizable (column, TRUE);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (tree), column);
 
@@ -585,15 +683,14 @@ gboolean bptree_init(move_to_line_cb cb)
 	g_object_set (condition_renderer, "ellipsize", PANGO_ELLIPSIZE_END, NULL);
 	g_signal_connect (G_OBJECT (condition_renderer), "edited", G_CALLBACK (on_condition_changed), NULL);
 	column = gtk_tree_view_column_new_with_attributes (_("Condition"), condition_renderer, "text", CONDITION, NULL);
-	gtk_tree_view_column_set_cell_data_func(column, condition_renderer, on_render, (gpointer)TRUE, NULL);
+	gtk_tree_view_column_set_cell_data_func(column, condition_renderer, on_render, NULL, NULL);
 	gtk_tree_view_column_set_resizable (column, TRUE);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (tree), column);
 	
 	/* hits count */
 	hcount_renderer = gtk_cell_renderer_spin_new ();
-	GtkAdjustment* adj = GTK_ADJUSTMENT (gtk_adjustment_new (0.0, 0.0, 100000.0, 1.0, 2.0, 2.0));
 	g_object_set (hcount_renderer,
-		"adjustment", adj,
+		"adjustment", gtk_adjustment_new (0.0, 0.0, 100000.0, 1.0, 2.0, 2.0),
         "digits", 0, NULL);
 	g_signal_connect (G_OBJECT (hcount_renderer), "edited", G_CALLBACK (on_hitscount_changed), NULL);
 	column = gtk_tree_view_column_new_with_attributes (_("Hit count"), hcount_renderer, "text", HITSCOUNT, NULL);
@@ -606,12 +703,6 @@ gboolean bptree_init(move_to_line_cb cb)
 	gtk_tree_view_column_set_visible(column, FALSE);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (tree), column);
 
-	/* enabled */
-	enable_renderer = gtk_cell_renderer_toggle_new ();
-	g_signal_connect (G_OBJECT(enable_renderer), "toggled", G_CALLBACK(on_activeness_changed), NULL);
-	column = gtk_tree_view_column_new_with_attributes (_("Enabled"), enable_renderer, "active", ENABLED, NULL);
-	gtk_tree_view_append_column (GTK_TREE_VIEW (tree), column);
-
 	/* Last invisible column */
 	renderer = gtk_cell_renderer_text_new ();
 	column = gtk_tree_view_column_new_with_attributes ("", renderer, "text", LAST_VISIBLE, NULL);
@@ -631,7 +722,7 @@ gboolean bptree_init(move_to_line_cb cb)
  * destroy breaks tree and associated data
  * arguments:
  */
-void bptree_destroy()
+void bptree_destroy(void)
 {
 	g_hash_table_destroy(files);
 }
@@ -643,10 +734,10 @@ void bptree_destroy()
  */
 void bptree_set_enabled(breakpoint *bp)
 {
-	gtk_tree_store_set(store, &(bp->iter), ENABLED, bp->enabled, -1);
-	bptree_update_break_icon(bp);
-
 	GtkTreeIter parent;
+
+	gtk_tree_store_set(store, &(bp->iter), ENABLED, bp->enabled, -1);
+
 	gtk_tree_model_iter_parent(model, &parent, &(bp->iter));
 	update_file_node(&parent);
 }
@@ -659,7 +750,6 @@ void bptree_set_enabled(breakpoint *bp)
 void bptree_set_hitscount(breakpoint *bp)
 {
   gtk_tree_store_set(store, &(bp->iter), HITSCOUNT, bp->hitscount, -1);
-  bptree_update_break_icon(bp);
 }
 
 /*
@@ -670,7 +760,6 @@ void bptree_set_hitscount(breakpoint *bp)
 void bptree_set_condition(breakpoint* bp)
 {
   gtk_tree_store_set(store, &(bp->iter), CONDITION, bp->condition, -1);
-  bptree_update_break_icon(bp);
 }
 
 /*
@@ -681,7 +770,7 @@ void bptree_set_condition(breakpoint* bp)
  */
 gchar* bptree_get_condition(breakpoint *bp)
 {
-    gchar *condition;
+	gchar *condition;
 	gtk_tree_model_get (
 		model,
 		&(bp->iter),
@@ -710,17 +799,20 @@ void bptree_set_readonly(gboolean value)
  */
 void bptree_add_breakpoint(breakpoint* bp)
 {
-	GtkTreeIter file_iter;
+	GtkTreeIter file_iter, iter, child, *sibling = NULL;
 	GtkTreeRowReference *file_reference = (GtkTreeRowReference*)g_hash_table_lookup(files, bp->file);
+
 	if (!file_reference)
 	{
+		GtkTreePath *file_path;
+
 		gtk_tree_store_prepend (store, &file_iter, NULL);
 		gtk_tree_store_set (store, &file_iter,
 						FILEPATH, bp->file,
 						ENABLED, TRUE,
 						-1);
 
-		GtkTreePath *file_path = gtk_tree_model_get_path(model, &file_iter);
+		file_path = gtk_tree_model_get_path(model, &file_iter);
 		file_reference = gtk_tree_row_reference_new(model, file_path);
 		gtk_tree_path_free(file_path);
 
@@ -728,11 +820,12 @@ void bptree_add_breakpoint(breakpoint* bp)
 	}
 	else
 	{
-		gtk_tree_model_get_iter(model, &file_iter, gtk_tree_row_reference_get_path(file_reference));
+		GtkTreePath *path = gtk_tree_row_reference_get_path(file_reference);
+		gtk_tree_model_get_iter(model, &file_iter, path);
+		gtk_tree_path_free(path);
 	}
 	
 	/* lookup where to insert new row */
-	GtkTreeIter child, *sibling = NULL;
 	if(gtk_tree_model_iter_children(model, &child, &file_iter))
 	{
 		do
@@ -752,11 +845,10 @@ void bptree_add_breakpoint(breakpoint* bp)
 		while(gtk_tree_model_iter_next(model, &child));
 	}
 	
-	GtkTreeIter iter;
 	gtk_tree_store_insert_before(store, &iter, &file_iter, sibling);
-    bp->iter = iter;
-    
-    bptree_update_breakpoint(bp);
+	bp->iter = iter;
+	
+	bptree_update_breakpoint(bp);
 }
 
 /*
@@ -776,8 +868,6 @@ void bptree_update_breakpoint(breakpoint* bp)
                     LINE, bp->line,
                     -1);
 	
-	bptree_update_break_icon(bp);
-
     g_free(location);
 }
 
@@ -808,7 +898,7 @@ void bptree_remove_breakpoint(breakpoint* bp)
  * updates all file ENABLED checkboxes base on theit children states
  * arguments:
  */
-void bptree_update_file_nodes()
+void bptree_update_file_nodes(void)
 {
 	GtkTreeIter file;
 	if(gtk_tree_model_iter_children(model, &file, NULL))
