@@ -144,7 +144,6 @@ static GList *read_only_pages = NULL;
 static module_description modules[] = 
 {
 	{ "GDB", &dbg_module_gdb },
-	/*{ "Bash", &dbg_module_bash },*/
 	{ NULL, NULL }
 };
 
@@ -152,46 +151,60 @@ static module_description modules[] =
 static GHashTable *calltips = NULL;
 
 /* 
- * removes stack margin markers
+ * remove stack margin markers
  */
- void remove_stack_markers()
+static void remove_stack_markers(void)
 {
-	frame *current = (frame*)stack->data;
-	if (current->have_source)
+	int active_frame_index = active_module->get_active_frame();
+	
+	GList *iter;
+	int frame_index;
+	for (iter = stack, frame_index = 0; iter; iter = iter->next, frame_index++)
 	{
-		markers_remove_current_instruction(current->file, current->line);
-	}
-	GList *iter = stack->next;
-	while (iter)
-	{
-		frame *next = (frame*)iter->data;
-		if (next->have_source)
+		if (iter)
 		{
-			markers_remove_frame(next->file, next->line);
+			frame *f = (frame*)iter->data;
+			if (f->have_source)
+			{
+				if (active_frame_index == frame_index)
+				{
+					markers_remove_current_instruction(f->file, f->line);
+				}
+				else
+				{
+					markers_remove_frame(f->file, f->line);
+				}
+			}
 		}
-		iter = iter->next;
 	}
 }
 
 /* 
- * removes stack margin markers
+ * add stack margin markers
  */
- void add_stack_markers()
+static void add_stack_markers(void)
 {
-	frame *current = (frame*)stack->data;
-	if (current->have_source)
+	int active_frame_index = active_module->get_active_frame();
+	
+	GList *iter;
+	int frame_index;
+	for (iter = stack, frame_index = 0; iter; iter = iter->next, frame_index++)
 	{
-		markers_add_current_instruction(current->file, current->line);
-	}
-	GList *iter = stack->next;
-	while (iter)
-	{
-		frame *next = (frame*)iter->data;
-		if (next->have_source)
+		if (iter)
 		{
-			markers_add_frame(next->file, next->line);
+			frame *f = (frame*)iter->data;
+			if (f->have_source)
+			{
+				if (active_frame_index == frame_index)
+				{
+					markers_add_current_instruction(f->file, f->line);
+				}
+				else
+				{
+					markers_add_frame(f->file, f->line);
+				}
+			}
 		}
-		iter = iter->next;
 	}
 }
 
@@ -206,30 +219,36 @@ static void on_watch_changed(GtkCellRendererText *renderer, gchar *path, gchar *
 {
 	/* get iterator to the changed row */
 	GtkTreeIter  iter;
+	gchar *oldvalue;
+	gchar *internal = NULL;
+	GtkTreePath *empty_path;
 	GtkTreePath *tree_path = gtk_tree_path_new_from_string (path);
+	gboolean is_empty_row;
+	gchar *striped;
+
 	gtk_tree_model_get_iter (
 		 gtk_tree_view_get_model(GTK_TREE_VIEW(wtree)),
 		 &iter,
 		 tree_path);
 	
 	/* get oldvalue */
-	gchar* oldvalue;
 	gtk_tree_model_get (
 		wmodel,
 		&iter,
 		W_NAME, &oldvalue,
-       -1);
-	gchar *internal = NULL;
-		gtk_tree_model_get (
+		-1);
+	gtk_tree_model_get (
 		wmodel,
 		&iter,
 		W_INTERNAL, &internal,
 		-1);
 
 	/* check if it is empty row */
-	gboolean is_empty_row = !gtk_tree_path_compare (tree_path, wtree_empty_path());
+	empty_path = wtree_empty_path();
+	is_empty_row = !gtk_tree_path_compare (tree_path, empty_path);
+	gtk_tree_path_free(empty_path);
 
-   	gchar *striped = g_strstrip(g_strdup(new_text));
+	striped = g_strstrip(g_strdup(new_text));
 	if (!strlen(striped) &&
 		!is_empty_row &&
 		dialogs_show_question(_("Delete variable?")))
@@ -257,8 +276,10 @@ static void on_watch_changed(GtkCellRendererText *renderer, gchar *path, gchar *
 		/* if debug is active - remove old watch and add new one */
 		if (DBS_STOPPED == debug_state)
 		{
+			variable *newvar;
+
 			active_module->remove_watch(internal);
-			variable *newvar = active_module->add_watch(striped);
+			newvar = active_module->add_watch(striped);
 			change_watch(GTK_TREE_VIEW(wtree), is_empty_row ? &newiter : &iter, newvar);
 		}
 		
@@ -291,14 +312,16 @@ static void on_watch_dragged_callback(GtkWidget *wgt, GdkDragContext *context, i
 {
 	/* string that is dragged */
 	gchar *expression = (gchar*)seldata->data;
-	
-	/* lookup for where the text has been dropped */
 	GtkTreePath *path = NULL;
 	GtkTreeViewDropPosition pos;
+	GtkTreePath *empty_path;
+	GtkTreeIter newvar;
+
+	/* lookup for where the text has been dropped */
 	gtk_tree_view_get_dest_row_at_pos(GTK_TREE_VIEW(wtree), x, y, &path, &pos);
 
 	/* if dropped into last row - insert before it */
-	GtkTreePath *empty_path = wtree_empty_path();
+	empty_path = wtree_empty_path();
 	if (!gtk_tree_path_compare(empty_path, path))
 		pos = GTK_TREE_VIEW_DROP_BEFORE;
 	gtk_tree_path_free(empty_path);
@@ -312,7 +335,6 @@ static void on_watch_dragged_callback(GtkWidget *wgt, GdkDragContext *context, i
 	}
 	
 	/* insert new row */
-	GtkTreeIter newvar;
 	if (path)
 	{
 		GtkTreeIter sibling;
@@ -325,7 +347,9 @@ static void on_watch_dragged_callback(GtkWidget *wgt, GdkDragContext *context, i
 	}
 	else
 	{
-		GtkTreeIter empty = wtree_empty_row();
+		GtkTreeIter empty;
+
+		wtree_empty_row(&empty);
 		gtk_tree_store_insert_before(wstore, &newvar, NULL, &empty);
 	}
 	
@@ -347,18 +371,21 @@ static void on_watch_dragged_callback(GtkWidget *wgt, GdkDragContext *context, i
  */
 static gboolean on_watch_key_pressed_callback(GtkWidget *widget, GdkEvent  *event, gpointer user_data)
 {
+	GtkTreeSelection *selection;
+	GList *rows;
+	GtkTreePath *empty_path;
+
 	/* handling only Delete button pressing
 	 * that means "delete selected rows" */
-	int keyval = ((GdkEventKey*)event)->keyval;
-	if (keyval != GDK_Delete)
+	if (((GdkEventKey*)event)->keyval != GDK_Delete)
 		return FALSE;
 
 	/* get selected rows */
-	GtkTreeSelection *selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(wtree));
-	GList *rows = gtk_tree_selection_get_selected_rows(selection, &wmodel);
+	selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(wtree));
+	rows = gtk_tree_selection_get_selected_rows(selection, &wmodel);
 	
 	/* empty row path */
-	GtkTreePath *empty_path = wtree_empty_path();
+	empty_path = wtree_empty_path();
 
 	/* check whether only empty row was selected */
 	if (1 != gtk_tree_selection_count_selected_rows(selection) ||
@@ -366,6 +393,7 @@ static gboolean on_watch_key_pressed_callback(GtkWidget *widget, GdkEvent  *even
 	{
 		/* path reference to select after deleteing finishes */
 		GtkTreeRowReference *reference_to_select = NULL;
+		GtkTreePath *path_to_select;
 
 		/* get references to the rows */
 		GList *references = NULL;
@@ -396,6 +424,7 @@ static gboolean on_watch_key_pressed_callback(GtkWidget *widget, GdkEvent  *even
 			current reference was already deleted */
 			if (gtk_tree_row_reference_valid(reference))
 			{
+				GtkTreeIter titer;
 				GtkTreePath *path = gtk_tree_row_reference_get_path(reference);
 
 				if (!reference_to_select)
@@ -413,7 +442,6 @@ static gboolean on_watch_key_pressed_callback(GtkWidget *widget, GdkEvent  *even
 				}
 
 				/* get iterator */
-				GtkTreeIter titer;
 				gtk_tree_model_get_iter(wmodel, &titer, path);
 
 				/* remove from the debug session, if it's active */
@@ -434,6 +462,8 @@ static gboolean on_watch_key_pressed_callback(GtkWidget *widget, GdkEvent  *even
 
 
 				gtk_tree_store_remove(wstore, &titer);
+
+				gtk_tree_path_free(path);
 			}
 			
 			iter = iter->next;
@@ -442,11 +472,15 @@ static gboolean on_watch_key_pressed_callback(GtkWidget *widget, GdkEvent  *even
 		/* if all (with or without empty row) was selected - set empty row
 		as a path to be selected after deleting */
 		if (!reference_to_select)
-			reference_to_select = gtk_tree_row_reference_new (gtk_tree_view_get_model(GTK_TREE_VIEW(wtree)), wtree_empty_path());
+		{
+			GtkTreePath *path = wtree_empty_path();
+			reference_to_select = gtk_tree_row_reference_new (gtk_tree_view_get_model(GTK_TREE_VIEW(wtree)), path);
+			gtk_tree_path_free(path);
+		}
 
 		/* set selection */
 		gtk_tree_selection_unselect_all(selection);
-		GtkTreePath *path_to_select = gtk_tree_row_reference_get_path(reference_to_select);
+		path_to_select = gtk_tree_row_reference_get_path(reference_to_select);
 		gtk_tree_selection_select_path(selection, path_to_select);
 		gtk_tree_view_scroll_to_cell(GTK_TREE_VIEW(widget), path_to_select, NULL, TRUE, 0.5, 0.5);
 		gtk_tree_path_free(path_to_select);	
@@ -458,6 +492,8 @@ static gboolean on_watch_key_pressed_callback(GtkWidget *widget, GdkEvent  *even
 		config_set_debug_changed();
 	}
 
+	gtk_tree_path_free(empty_path);
+
 	/* free rows list */
 	g_list_foreach (rows, (GFunc)gtk_tree_path_free, NULL);
 	g_list_free (rows);
@@ -468,7 +504,7 @@ static gboolean on_watch_key_pressed_callback(GtkWidget *widget, GdkEvent  *even
 /* 
  * mouse button has been pressed while being in watch(autos) tree view
  */
-gboolean on_watch_button_pressed_callback(GtkWidget *treeview, GdkEventButton *event, gpointer userdata)
+static gboolean on_watch_button_pressed_callback(GtkWidget *treeview, GdkEventButton *event, gpointer userdata)
 {
     if (event->type == GDK_2BUTTON_PRESS  &&  event->button == 1)
 	{
@@ -477,19 +513,20 @@ gboolean on_watch_button_pressed_callback(GtkWidget *treeview, GdkEventButton *e
 			GTK_TREE_VIEW(treeview),
 		    (int)event->x, (int)event->y, &path, NULL, NULL, NULL))
 		{
+			gchar *expression = NULL;
 			GtkTreeIter iter;
 			GtkTreeModel *model = gtk_tree_view_get_model(GTK_TREE_VIEW(treeview));
 			gtk_tree_model_get_iter (model, &iter, path);
 
-			gchar *expression = NULL;
 			gtk_tree_model_get(model, &iter,
 				W_EXPRESSION, &expression,
-			    NULL);
+			    -1);
 
 			if (strlen(expression))
 			{
-				GtkTreeIter newvar;
-				GtkTreeIter empty = wtree_empty_row();
+				GtkTreeIter newvar, empty;
+
+				wtree_empty_row(&empty);
 				gtk_tree_store_insert_before(wstore, &newvar, NULL, &empty);
 			
 				/* if debugger is active (in stopped condition) - add to run-time watch list
@@ -533,8 +570,10 @@ static void on_watch_expanded_callback(GtkTreeView *tree, GtkTreeIter *iter, Gtk
 	
 	if (only_stub)
 	{
-		/* if item has not been expanded before */
+		GList *children;
 		gchar *internal;
+
+		/* if item has not been expanded before */
 		gtk_tree_model_get (
 			model,
 			iter,
@@ -542,7 +581,7 @@ static void on_watch_expanded_callback(GtkTreeView *tree, GtkTreeIter *iter, Gtk
 			-1);
 		
 		/* get children list */
-		GList *children = active_module->get_children(internal);
+		children = active_module->get_children(internal);
 		
 		/* remove stub and add children */
 		expand_stub(tree, iter, children);
@@ -582,7 +621,7 @@ static void enable_sensitive_widgets(gboolean enable)
 /* 
  * called from debug module when debugger is being run 
  */
-static void on_debugger_run ()
+static void on_debugger_run (void)
 {
 	/* update debug state */
 	debug_state = DBS_RUNNING;
@@ -591,8 +630,11 @@ static void on_debugger_run ()
 	if (stack)
 	{
 		remove_stack_markers();
+		g_list_foreach(stack, (GFunc)frame_free, NULL);
 		g_list_free(stack);
 		stack = NULL;
+
+		stree_remove_frames();
 	}
 
 	/* disable widgets */
@@ -606,8 +648,10 @@ static void on_debugger_run ()
 /* 
  * called from debug module when debugger is being stopped 
  */
-static void on_debugger_stopped ()
+static void on_debugger_stopped (int thread_id)
 {
+	GList *iter, *files, *autos, *watches;
+
 	/* update debug state */
 	debug_state = DBS_STOPPED;
 
@@ -641,22 +685,19 @@ static void on_debugger_stopped ()
 	}
 
 	/* clear stack tree view */
-	stree_clear();
+	stree_set_active_thread_id(thread_id);
 
 	/* get current stack trace and put in the tree view */
 	stack = active_module->get_stack();
-	
-	GList *iter = stack;
-	while (iter)
+	for (iter = stack; iter; iter = iter->next)
 	{
 		frame *f = (frame*)iter->data;
-		stree_add(f, iter == stack);
-		iter = g_list_next(iter);
+		stree_add(f);
 	}
-	stree_select_first();
+	stree_select_first_frame(TRUE);
 
 	/* files */
-	GList *files = active_module->get_files();
+	files = active_module->get_files();
 	/* remove from list and make writable those files,
 	that are not in the current list */
 	iter = read_only_pages;
@@ -664,6 +705,8 @@ static void on_debugger_stopped ()
 	{
 		if (!g_list_find_custom(files, iter->data, (GCompareFunc)g_strcmp0))
 		{
+			GList *next;
+
 			/* set document writable */
 			GeanyDocument *doc = document_find_by_real_path((const gchar*)iter->data);
 			if (doc)
@@ -672,7 +715,7 @@ static void on_debugger_stopped ()
 			/* free file name */
 			g_free(iter->data);
 			/* save next item pointer */
-			GList *next = iter->next;
+			next = iter->next;
 			/* remove current item */
 			read_only_pages = g_list_delete_link(read_only_pages, iter);
 
@@ -703,11 +746,11 @@ static void on_debugger_stopped ()
 	g_list_free(files);
 
 	/* autos */
-	GList *autos = active_module->get_autos();
+	autos = active_module->get_autos();
 	update_variables(GTK_TREE_VIEW(atree), NULL, autos);
 	
 	/* watches */
-	GList *watches = active_module->get_watches();
+	watches = active_module->get_watches();
 	update_variables(GTK_TREE_VIEW(wtree), NULL, watches);
 
 	if (stack)
@@ -737,10 +780,15 @@ static void on_debugger_stopped ()
  */
 static void on_debugger_exited (int code)
 {
+	GtkTextIter start, end;
+	GtkTextBuffer *buffer;
+	GList *iter;
+
 	/* remove marker for current instruction if was set */
 	if (stack)
 	{
 		remove_stack_markers();
+		g_list_foreach(stack, (GFunc)frame_free, NULL);
 		g_list_free(stack);
 		stack = NULL;
 	}
@@ -758,8 +806,7 @@ static void on_debugger_exited (int code)
 	vte_terminal_reset(VTE_TERMINAL(terminal), TRUE, TRUE);
 
 	/* clear debug messages window */
-	GtkTextIter start, end;
-	GtkTextBuffer *buffer = gtk_text_view_get_buffer(GTK_TEXT_VIEW(debugger_messages_textview));
+	buffer = gtk_text_view_get_buffer(GTK_TEXT_VIEW(debugger_messages_textview));
 	gtk_text_buffer_get_bounds(buffer, &start, &end);
 	gtk_text_buffer_delete(buffer, &start, &end);
 
@@ -771,8 +818,7 @@ static void on_debugger_exited (int code)
 		bptree_set_readonly(FALSE);
 	
 	/* set files that was readonly during debug writable */
-	GList *iter = read_only_pages;
-	while (iter)
+	for (iter = read_only_pages; iter; iter = iter->next)
 	{
 		GeanyDocument *doc = document_find_by_real_path((const gchar*)iter->data);
 		if (doc)
@@ -780,8 +826,6 @@ static void on_debugger_exited (int code)
 
 		/* free file name */
 		g_free(iter->data);
-
-		iter = iter->next;
 	}
 	g_list_free(read_only_pages);
 	read_only_pages = NULL;
@@ -821,7 +865,7 @@ static void on_debugger_message (const gchar* message, const gchar *color)
 /* 
  * called from debugger module to clear messages tab 
  */
-static void on_debugger_messages_clear ()
+static void on_debugger_messages_clear (void)
 {
 	/* clear debug messages window */
 	GtkTextIter start, end;
@@ -838,6 +882,22 @@ static void on_debugger_error (const gchar* message)
 	dialogs_show_msgbox(GTK_MESSAGE_ERROR, "%s", message);
 }
 
+/* 
+ * called from debugger module when a thead has been removed 
+ */
+static void on_thread_removed(int thread_id)
+{
+	stree_remove_thread(thread_id);
+}
+
+/* 
+ * called from debugger module when a new thead has been added 
+ */
+static void on_thread_added (int thread_id)
+{
+	stree_add_thread(thread_id);
+}
+
 /* callbacks structure to pass to debugger module */
 dbg_callbacks callbacks = {
 	on_debugger_run,
@@ -846,18 +906,55 @@ dbg_callbacks callbacks = {
 	on_debugger_message,
 	on_debugger_messages_clear,
 	on_debugger_error,
+	on_thread_added,
+	on_thread_removed,
 };
 
 /*
  * Interface functions
  */
 
+/* 
+ * called when a frame in the stack tree has been selected 
+ */
+static void on_select_frame(int frame_number)
+{
+	GList *autos, *watches;
+	frame *f = (frame*)g_list_nth(stack, active_module->get_active_frame())->data;
+	markers_remove_current_instruction(f->file, f->line);
+	markers_add_frame(f->file, f->line);
+
+	active_module->set_active_frame(frame_number);
+	
+	/* clear calltips cache */
+	g_hash_table_remove_all(calltips);
+	
+	/* autos */
+	autos = active_module->get_autos();
+	update_variables(GTK_TREE_VIEW(atree), NULL, autos);
+	
+	/* watches */
+	watches = active_module->get_watches();
+	update_variables(GTK_TREE_VIEW(wtree), NULL, watches);
+
+	f = (frame*)g_list_nth(stack, frame_number)->data;
+	markers_remove_frame(f->file, f->line);
+	markers_add_current_instruction(f->file, f->line);
+}
+
 /*
  * init debug related GUI (watch tree view)
  * arguments:
  */
-void debug_init()
+void debug_init(void)
 {
+	GtkWidget *scrollbar;
+	GtkWidget *hbox;
+	GKeyFile *config;
+	gchar *configfile;
+	gchar *font;
+	GtkTextBuffer *buffer;
+
 	/* create watch page */
 	wtree = wtree_init(on_watch_expanded_callback,
 		on_watch_dragged_callback,
@@ -888,7 +985,7 @@ void debug_init()
 	gtk_container_add(GTK_CONTAINER(tab_autos), atree);
 	
 	/* create stack trace page */
-	stree = stree_init(editor_open_position);
+	stree = stree_init(editor_open_position, on_select_frame);
 	tab_call_stack = gtk_scrolled_window_new(
 		gtk_tree_view_get_hadjustment(GTK_TREE_VIEW(stree )),
 		gtk_tree_view_get_vadjustment(GTK_TREE_VIEW(stree ))
@@ -907,11 +1004,11 @@ void debug_init()
 	grantpt(pty_master);
 	unlockpt(pty_master);
 	vte_terminal_set_pty(VTE_TERMINAL(terminal), pty_master);
-	GtkWidget *scrollbar = gtk_vscrollbar_new(GTK_ADJUSTMENT(VTE_TERMINAL(terminal)->adjustment));
+	scrollbar = gtk_vscrollbar_new(GTK_ADJUSTMENT(VTE_TERMINAL(terminal)->adjustment));
 	GTK_WIDGET_UNSET_FLAGS(scrollbar, GTK_CAN_FOCUS);
 	tab_terminal = gtk_frame_new(NULL);
 	gtk_frame_set_shadow_type (GTK_FRAME(tab_terminal), GTK_SHADOW_NONE);
-	GtkWidget *hbox = gtk_hbox_new(FALSE, 0);
+	hbox = gtk_hbox_new(FALSE, 0);
 	gtk_container_add(GTK_CONTAINER(tab_terminal), hbox);
 	gtk_box_pack_start(GTK_BOX(hbox), terminal, TRUE, TRUE, 0);
 	gtk_box_pack_start(GTK_BOX(hbox), scrollbar, FALSE, FALSE, 0);
@@ -920,10 +1017,10 @@ void debug_init()
 	gtk_widget_set_size_request(GTK_WIDGET(terminal), 10, 10);
 	vte_terminal_set_size(VTE_TERMINAL(terminal), 30, 1);
 	/* set terminal font. */
-	GKeyFile *config = g_key_file_new();
-	gchar *configfile = g_strconcat(geany_data->app->configdir, G_DIR_SEPARATOR_S, "geany.conf", NULL);
+	config = g_key_file_new();
+	configfile = g_strconcat(geany_data->app->configdir, G_DIR_SEPARATOR_S, "geany.conf", NULL);
 	g_key_file_load_from_file(config, configfile, G_KEY_FILE_NONE, NULL);
-	gchar *font = utils_get_setting_string(config, "VTE", "font", "Monospace 10");
+	font = utils_get_setting_string(config, "VTE", "font", "Monospace 10");
 	vte_terminal_set_font_from_string (VTE_TERMINAL(terminal), font);	
 		
 	/* debug messages page */
@@ -939,7 +1036,7 @@ void debug_init()
 	gtk_scrolled_window_add_with_viewport(GTK_SCROLLED_WINDOW(tab_messages), debugger_messages_textview);
 	
 	/* create tex tags */
-	GtkTextBuffer *buffer = gtk_text_view_get_buffer(GTK_TEXT_VIEW(debugger_messages_textview));
+	buffer = gtk_text_view_get_buffer(GTK_TEXT_VIEW(debugger_messages_textview));
 	gtk_text_buffer_create_tag(buffer, "black", "foreground", "#000000", NULL); 
 	gtk_text_buffer_create_tag(buffer, "grey", "foreground", "#AAAAAA", NULL); 
 	gtk_text_buffer_create_tag(buffer, "red", "foreground", "#FF0000", NULL); 
@@ -953,7 +1050,7 @@ void debug_init()
 /*
  * called when plugin is being unloaded to remove current instruction marker
  */
-void debug_destroy()
+void debug_destroy(void)
 {
 	/* close PTY file descriptors */
 	close(pty_master);
@@ -963,6 +1060,7 @@ void debug_destroy()
 	if (stack)
 	{
 		remove_stack_markers();
+		g_list_foreach(stack, (GFunc)frame_free, NULL);
 		g_list_free(stack);
 		stack = NULL;
 	}
@@ -973,7 +1071,7 @@ void debug_destroy()
 /*
  * gets current debug state
  */
-enum dbs debug_get_state()
+enum dbs debug_get_state(void)
 {
 	return debug_state;
 }
@@ -981,7 +1079,7 @@ enum dbs debug_get_state()
 /*
  * gets current stack frames lisy
  */
-GList* debug_get_stack()
+GList* debug_get_stack(void)
 {
 	return stack;
 }
@@ -1007,7 +1105,7 @@ int debug_get_module_index(const gchar *modulename)
 /*
  * gets GList with all debug modules pointers
  */
-GList* debug_get_modules()
+GList* debug_get_modules(void)
 {
 	GList *mods = NULL;
 	module_description *desc = modules;
@@ -1023,7 +1121,7 @@ GList* debug_get_modules()
 /*
  * checks whether currently active debug module supports asyncronous breaks
  */
-gboolean debug_supports_async_breaks()
+gboolean debug_supports_async_breaks(void)
 {
 	return active_module->features & MF_ASYNC_BREAKS;
 }
@@ -1031,80 +1129,46 @@ gboolean debug_supports_async_breaks()
 /*
  * starts or continues debug process
  */
-void debug_run()
+void debug_run(void)
 {
 	if (DBS_IDLE == debug_state)
 	{
-		/* init selected debugger  module */
-	    if((active_module = modules[tpage_get_debug_module_index()].module)->init(&callbacks))
+		gchar *target, *commandline;
+		GList *env, *watches, *breaks;
+
+		target = g_strstrip(tpage_get_target());
+		if (!strlen(target))
 		{
-			/* gets parameters from the target page */
-			gchar *target = g_strstrip(tpage_get_target());
-			if (!strlen(target))
-			{
-				g_free(target);
-				return;
-			}
-			gchar *commandline = tpage_get_commandline();
-			GList *env = tpage_get_environment();
-
-			/* collect watches */
-			GList *watches = get_root_items(GTK_TREE_VIEW(wtree));
-
-			/* load file */
-			if (active_module->load(target, commandline, env, watches))
-			{
-				/* set breaks */
-
-				GList *breaks = breaks_get_all();
-
-				GList *iter = breaks;
-				while (iter)
-				{
-					breakpoint *bp = (breakpoint*)iter->data;
-					if(!active_module->set_break(bp, BSA_NEW_BREAK))
-					{
-						break;
-					}
-					iter = iter->next;
-				}
-
-				if (iter)
-				{
-					breakpoint *bad_break = (breakpoint*)iter->data;
-					gchar msg[1000];
-					sprintf(msg, _("Breakpoint at %s:%i cannot be set\nDebugger message: %s"),
-						bad_break->file, bad_break->line, active_module->error_message());
-						
-					dialogs_show_msgbox(GTK_MESSAGE_ERROR, "%s", msg);
-						
-					active_module->stop();
-					debug_state = DBS_STOP_REQUESTED;
-					return;
-				}
-
-				g_list_free(breaks);
-				
-				/* set target page - readonly */
-				tpage_set_readonly(TRUE);
-				
-				/* run */
-				active_module->run(ttyname(pty_slave));
-
-				/* update debuf state */
-				debug_state = DBS_RUN_REQUESTED;
-			}
-			
-			/* free watch list */
-			g_list_foreach(watches, (GFunc)g_free, NULL);
-			g_list_free(watches);
-
-			/* free target related values */
 			g_free(target);
-			g_free(commandline);
-			g_list_foreach(env, (GFunc)g_free, NULL);
-			g_list_free(env);
+			return;
 		}
+		commandline = tpage_get_commandline();
+		env = tpage_get_environment();
+		watches = get_root_items(GTK_TREE_VIEW(wtree));
+		breaks = breaks_get_all();
+
+		/* init selected debugger  module */
+		active_module = modules[tpage_get_debug_module_index()].module;
+		if(active_module->run(target, commandline, env, watches, breaks, ttyname(pty_slave), &callbacks))
+		{
+			/* set target page - readonly */
+			tpage_set_readonly(TRUE);
+
+			/* update debuf state */
+			debug_state = DBS_RUN_REQUESTED;
+		}
+
+		/* free stuff */
+		g_free(target);
+		g_free(commandline);
+
+		g_list_foreach(env, (GFunc)g_free, NULL);
+		g_list_free(env);
+
+		g_list_foreach(watches, (GFunc)g_free, NULL);
+		g_list_free(watches);
+
+		g_list_free(breaks);
 	}
 	else if (DBS_STOPPED == debug_state)
 	{
@@ -1121,7 +1185,7 @@ void debug_run()
 /*
  * restarts debug process
  */
-void debug_restart()
+void debug_restart(void)
 {
 	if (DBS_STOPPED == debug_state)
 	{
@@ -1135,7 +1199,7 @@ void debug_restart()
 /*
  * stops debug process
  */
-void debug_stop()
+void debug_stop(void)
 {
 	if (DBS_STOPPED == debug_state)
 	{
@@ -1154,7 +1218,7 @@ void debug_stop()
 /*
  * step over
  */
-void debug_step_over()
+void debug_step_over(void)
 {
 	if (DBS_STOPPED == debug_state)
 		active_module->step_over();
@@ -1163,7 +1227,7 @@ void debug_step_over()
 /*
  * step into
  */
-void debug_step_into()
+void debug_step_into(void)
 {
 	if (DBS_STOPPED == debug_state)
 		active_module->step_into();
@@ -1172,7 +1236,7 @@ void debug_step_into()
 /*
  * step out
  */
-void debug_step_out()
+void debug_step_out(void)
 {
 	if (DBS_STOPPED == debug_state)
 		active_module->step_out();
@@ -1235,7 +1299,7 @@ void debug_request_interrupt(bs_callback cb, gpointer data)
 /*
  * gets debug modules error message
  */
-gchar* debug_error_message()
+gchar* debug_error_message(void)
 {
 	return 	active_module->error_message();	
 }
@@ -1304,7 +1368,7 @@ gchar* debug_get_calltip_for_expression(gchar* expression)
  * check whether source for the current instruction
  * is avaiable
  */
-gboolean debug_current_instruction_have_sources()
+gboolean debug_current_instruction_have_sources(void)
 {
 	frame *current = (frame*)stack->data;
 	return current->have_source ? strlen(current->file) : 0;
@@ -1313,7 +1377,7 @@ gboolean debug_current_instruction_have_sources()
 /*
  * opens position according to the current instruction
  */
-void debug_jump_to_current_instruction()
+void debug_jump_to_current_instruction(void)
 {
 	frame *current = (frame*)stack->data;
 	editor_open_position(current->file, current->line);
@@ -1329,3 +1393,11 @@ void debug_on_file_open(GeanyDocument *doc)
 	if (g_list_find_custom(read_only_pages, (gpointer)file, (GCompareFunc)g_strcmp0))
 		scintilla_send_message(doc->editor->sci, SCI_SETREADONLY, 1, 0);
 }
+
+/*
+ * get active frame index
+ */
+int debug_get_active_frame(void)
+{
+	return active_module->get_active_frame();
+}
