@@ -24,6 +24,10 @@
  */
 
 
+#ifdef HAVE_CONFIG_H
+# include "config.h" /* for the gettext domain */
+#endif
+
 #include "ggd-file-type-loader.h"
 
 #include <string.h>
