@@ -17,6 +17,10 @@
  *  along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
+#ifdef HAVE_CONFIG_H
+# include "config.h"
+#endif
+
 #include <ctype.h>
 #include <limits.h>
 #include <stdlib.h>
@@ -153,6 +157,7 @@ static void insert_numbers(gboolean *cancel)
 			if (*cancel)
 			{
 				ui_progress_bar_stop();
+				g_free(line_pos);
 				return;
 			}
 		}
@@ -239,6 +244,7 @@ static void insert_numbers(gboolean *cancel)
 
 	sci_end_undo_action(sci);
 	g_free(buffer);
+	g_free(line_pos);
 	ui_progress_bar_stop();
 }
 
