@@ -1,7 +1,7 @@
 /*
  *	  geanylatex.c - Plugin to let Geany better work together with LaTeX
  *
- *	  Copyright 2007-2011 Frank Lanitz <frank(at)frank(dot)uvena(dot)de>
+ *	  Copyright 2007-2012 Frank Lanitz <frank(at)frank(dot)uvena(dot)de>
  *	  Copyright 2005-2009 Enrico Tröger <enrico(dot)troeger(at)uvena(dot)de>
  *	  Copyright 2006-2009 Nick Treleaven <nick(dot)treleaven(at)btinternet(dot)com>
  *
@@ -40,7 +40,7 @@ PLUGIN_SET_TRANSLATABLE_INFO(
 	GETTEXT_PACKAGE,
 	_("GeanyLaTeX"),
 	_("Plugin to provide better LaTeX support"),
-	"0.6",
+	"0.7",
 	"Frank Lanitz <frank@frank.uvena.de>")
 
 GeanyPlugin	 *geany_plugin;
@@ -49,6 +49,8 @@ GeanyFunctions  *geany_functions;
 
 /* Widgets for plugin */
 static GtkWidget *menu_latex = NULL;
+static GtkWidget *menu_bibtex = NULL;
+static GtkWidget *menu_bibtex_menu = NULL;
 static GtkWidget *menu_latex_menu = NULL;
 static GtkWidget *menu_latex_wizard = NULL;
 static GtkWidget *menu_latex_menu_special_char = NULL;
@@ -91,12 +93,12 @@ static gboolean glatex_autocompletion_active = FALSE;
 static gint glatex_autocompletion_context_size;
 static gboolean glatex_autocompletion_only_for_latex;
 gboolean glatex_autobraces_active = TRUE;
+gboolean glatex_lowercase_on_smallcaps = FALSE;
+
 
 /* Function will be deactivated, when only loaded */
 static gboolean toggle_active = FALSE;
 
-static GtkWidget *main_menu_item = NULL;
-
 static GtkUIManager *uim;
 static GtkActionGroup *group;
 static GtkWidget *glatex_toolbar = NULL;
@@ -124,7 +126,7 @@ const guint ui_entries_n = G_N_ELEMENTS(format_icons);
 
 
 /* fallback UI definition */
-const gchar *toolbar_markup =
+static const gchar *toolbar_markup =
 "<ui>"
 	"<toolbar name='glatex_format_toolbar'>"
 		"<toolitem action='Wizard'/>"
@@ -146,6 +148,7 @@ static struct
 	GtkWidget *glatex_autocompletion_active;
 	GtkWidget *glatex_capitalize_sentence;
 	GtkWidget *wizard_to_generic_toolbar;
+	GtkWidget *lower_selection_on_smallcaps;
 }
 config_widgets;
 
@@ -157,7 +160,7 @@ static void add_wizard_to_generic_toolbar(void);
 static void remove_wizard_from_generic_toolbar(void);
 
 
-static GtkWidget *init_toolbar()
+static GtkWidget *init_toolbar(void)
 {
 	GtkWidget *toolbar = NULL;
 
@@ -201,6 +204,8 @@ on_configure_response(G_GNUC_UNUSED GtkDialog *dialog, gint response,
 			gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(config_widgets.glatex_capitalize_sentence));
 		glatex_wizard_to_generic_toolbar =
 			gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(config_widgets.wizard_to_generic_toolbar));
+		glatex_lowercase_on_smallcaps =
+			gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(config_widgets.lower_selection_on_smallcaps));
 
 		/* Check the response code for geanyLaTeX's autocompletion functions.
 		 * Due compatibility with oder Geany versions cass 0 will be treated
@@ -221,6 +226,8 @@ on_configure_response(G_GNUC_UNUSED GtkDialog *dialog, gint response,
 			glatex_set_toolbar_active);
 		g_key_file_set_boolean(config, "general", "glatex_set_autocompletion",
 			glatex_autocompletion_active);
+		g_key_file_set_boolean(config, "general", "glatex_lowercase_on_smallcaps",
+			glatex_lowercase_on_smallcaps);
 		g_key_file_set_boolean(config, "autocompletion",
 			"glatex_capitalize_sentence_starts", glatex_capitalize_sentence_starts);
 		g_key_file_set_boolean(config, "toolbar", "glatex_wizard_to_generic_toolbar",
@@ -295,6 +302,8 @@ plugin_configure(GtkDialog * dialog)
 		_("Capitalize sentence on typing"));
 	config_widgets.wizard_to_generic_toolbar = gtk_check_button_new_with_label(
 		_("Add a wizard icon to Geany's main toolbar"));
+	config_widgets.lower_selection_on_smallcaps = gtk_check_button_new_with_label(
+		_("Lower selection when formating smallcaps (\\textsc{})"));
 
 	config_widgets.glatex_autocompletion_active = gtk_combo_box_new_text();
 	gtk_combo_box_insert_text(GTK_COMBO_BOX(config_widgets.glatex_autocompletion_active), 0,
@@ -310,6 +319,7 @@ plugin_configure(GtkDialog * dialog)
 		tmp = 1;
 	else
 		tmp = 0;
+
 	gtk_combo_box_set_active(GTK_COMBO_BOX(config_widgets.glatex_autocompletion_active), tmp);
 
 	label_autocompletion = gtk_label_new(_("Modus of autocompletion"));
@@ -328,6 +338,9 @@ plugin_configure(GtkDialog * dialog)
 	gtk_box_pack_start(GTK_BOX(vbox), config_widgets.glatex_capitalize_sentence, FALSE, FALSE, 2);
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(config_widgets.wizard_to_generic_toolbar),
 		glatex_wizard_to_generic_toolbar);
+	gtk_box_pack_start(GTK_BOX(vbox), config_widgets.lower_selection_on_smallcaps, FALSE, FALSE, 2);
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(config_widgets.lower_selection_on_smallcaps),
+		glatex_lowercase_on_smallcaps);
 	gtk_box_pack_start(GTK_BOX(vbox), config_widgets.wizard_to_generic_toolbar, FALSE, FALSE, 2);
 	gtk_box_pack_start(GTK_BOX(vbox), hbox_autocompletion, FALSE, FALSE, 2);
 
@@ -363,13 +376,13 @@ static void toggle_toolbar_item(const gchar *path, gboolean new_status)
 static void
 check_for_menu(gint ft_id)
 {
-	if (ft_id == GEANY_FILETYPES_LATEX &&
-		main_menu_item == NULL)
+	/* We don't check whether the menu has been added here, as this
+	 * will is checked by add_menu_to_menubar() anyway */
+	if (ft_id == GEANY_FILETYPES_LATEX)
 	{
 		add_menu_to_menubar();
 	}
-	if (ft_id != GEANY_FILETYPES_LATEX &&
-		main_menu_item != NULL)
+	if (ft_id != GEANY_FILETYPES_LATEX)
 	{
 		if (glatex_deactivate_menubarentry_with_non_latex == TRUE)
 		{
@@ -379,7 +392,7 @@ check_for_menu(gint ft_id)
 }
 
 
-static void activate_toolbar_items()
+static void activate_toolbar_items(void)
 {
 	if (uim == NULL)
 	{
@@ -395,7 +408,7 @@ static void activate_toolbar_items()
 	gtk_ui_manager_ensure_update(uim);
 }
 
-static void deactivate_toolbar_items()
+static void deactivate_toolbar_items(void)
 {
 	if (uim == NULL)
 	{
@@ -467,10 +480,7 @@ on_geany_startup_complete(G_GNUC_UNUSED GObject *obj,
 		if (glatex_add_menu_on_startup == TRUE||
 			doc->file_type->id == GEANY_FILETYPES_LATEX)
 		{
-			if (main_menu_item == NULL)
-			{
-				add_menu_to_menubar();
-			}
+			add_menu_to_menubar();
 		}
 	}
 
@@ -1605,11 +1615,11 @@ on_wizard_response(G_GNUC_UNUSED GtkDialog *dialog, gint response,
 				gchar* author_string = NULL;
 				if (documentclass_int == 3)
 				{
-					utils_string_replace_all(code, "{AUTHOR}", "\% \\signature{}\n");
+					utils_string_replace_all(code, "{AUTHOR}", "% \\signature{}\n");
 				}
 				else
 				{
-					utils_string_replace_all(code, "{AUTHOR}", "\% \\author{}\n");
+					utils_string_replace_all(code, "{AUTHOR}", "% \\author{}\n");
 				}
 				utils_string_replace_all(code, "{AUTHOR}", author_string);
 				if (author != NULL)
@@ -1629,7 +1639,7 @@ on_wizard_response(G_GNUC_UNUSED GtkDialog *dialog, gint response,
 			}
 			else
 			{
-				utils_string_replace_all(code, "{DATE}", "\% \\date{}\n");
+				utils_string_replace_all(code, "{DATE}", "% \\date{}\n");
 				if (date != NULL)
 				{
 					g_free(date);
@@ -1656,11 +1666,11 @@ on_wizard_response(G_GNUC_UNUSED GtkDialog *dialog, gint response,
 			{
 				if (documentclass_int == 3)
 				{
-					utils_string_replace_all(code, "{TITLE}", "\% \\subject{} \n");
+					utils_string_replace_all(code, "{TITLE}", "% \\subject{} \n");
 				}
 				else
 				{
-					utils_string_replace_all(code, "{TITLE}", "\% \\title{} \n");
+					utils_string_replace_all(code, "{TITLE}", "% \\title{} \n");
 				}
 				if (title != NULL)
 				{
@@ -1908,7 +1918,7 @@ glatex_wizard_activated(G_GNUC_UNUSED GtkMenuItem * menuitem,
 	gtk_widget_show_all(dialog);
 }
 
-static void init_keybindings()
+static void init_keybindings(void)
 {
 	GeanyKeyGroup *key_group;
 
@@ -1972,7 +1982,7 @@ static void init_keybindings()
 }
 
 
-void plugin_help()
+void plugin_help(void)
 {
 	dialogs_show_msgbox(GTK_MESSAGE_INFO,
 		_("GeanyLaTeX is a plugin to improve support for LaTeX in Geany."
@@ -1981,7 +1991,7 @@ void plugin_help()
 }
 
 
-static void glatex_init_configuration()
+static void glatex_init_configuration(void)
 {
 	GKeyFile *config = g_key_file_new();
 
@@ -2001,6 +2011,8 @@ static void glatex_init_configuration()
 		"glatex_set_autocompletion", TRUE);
 	glatex_autobraces_active = utils_get_setting_boolean(config, "autocompletion",
 		"glatex_set_autobraces", TRUE);
+	glatex_lowercase_on_smallcaps = utils_get_setting_boolean(config, "general",
+		"glatex_lowercase_on_smallcaps", FALSE);
 
 	/* Hidden preferences. Can be set directly via configuration file*/
 	glatex_autocompletion_context_size = utils_get_setting_integer(config, "autocompletion",
@@ -2051,7 +2063,7 @@ static void glatex_init_configuration()
 
 
 static void
-add_wizard_to_generic_toolbar()
+add_wizard_to_generic_toolbar(void)
 {
 	if (glatex_wizard_generic_toolbar_item == NULL)
 	{
@@ -2067,7 +2079,7 @@ add_wizard_to_generic_toolbar()
 
 
 static void
-remove_wizard_from_generic_toolbar()
+remove_wizard_from_generic_toolbar(void)
 {
 	if (glatex_wizard_generic_toolbar_item != NULL)
 	{
@@ -2078,7 +2090,7 @@ remove_wizard_from_generic_toolbar()
 
 
 static void
-add_menu_to_menubar()
+add_menu_to_menubar(void)
 {
 	GtkWidget *tmp = NULL;
 	gint i;
@@ -2088,190 +2100,216 @@ add_menu_to_menubar()
 	menubar = GTK_MENU_SHELL(
 				ui_lookup_widget(geany->main_widgets->window, "menubar1"));
 
-	/* Then we build up the menu and finally add it */
-	menu_latex = gtk_menu_item_new_with_mnemonic(_("_LaTeX"));
-	gtk_menu_shell_insert(
-		menubar,menu_latex, g_list_length(menubar->children)- 1);
-
-	menu_latex_menu = gtk_menu_new();
-	gtk_menu_item_set_submenu(GTK_MENU_ITEM(menu_latex), menu_latex_menu);
-
-	menu_latex_wizard = ui_image_menu_item_new(GTK_STOCK_NEW, _("LaTeX-_Wizard"));
-	gtk_container_add(GTK_CONTAINER(menu_latex_menu), menu_latex_wizard);
-	ui_widget_set_tooltip_text(menu_latex_wizard,
-				 _("Starts a Wizard to easily create LaTeX-documents"));
-
-	g_signal_connect(menu_latex_wizard, "activate",
-			 G_CALLBACK(glatex_wizard_activated), NULL);
-
-	menu_latex_menu_special_char = gtk_menu_item_new_with_mnemonic(_("I_nsert Special Character"));
-	ui_widget_set_tooltip_text(menu_latex_menu_special_char,
-				 _("Helps to use some not very common letters and signs"));
-	gtk_container_add(GTK_CONTAINER(menu_latex_menu),
-		menu_latex_menu_special_char);
-
-	menu_latex_menu_special_char_submenu = gtk_menu_new();
-	gtk_menu_item_set_submenu(GTK_MENU_ITEM(menu_latex_menu_special_char),
-		menu_latex_menu_special_char_submenu);
-	glatex_sub_menu_init(menu_latex_menu_special_char_submenu,
-		glatex_char_array, glatex_cat_names, char_insert_activated);
-
-	menu_latex_ref = gtk_menu_item_new_with_mnemonic(_("Insert _Reference"));
-	ui_widget_set_tooltip_text(menu_latex_ref,
-		_("Inserting references to the document"));
-	gtk_container_add(GTK_CONTAINER(menu_latex_menu), menu_latex_ref);
-	g_signal_connect(menu_latex_ref, "activate",
-		G_CALLBACK(glatex_insert_ref_activated), NULL);
-
-	menu_latex_label = gtk_menu_item_new_with_mnemonic(_("Insert _Label"));
-	ui_widget_set_tooltip_text(menu_latex_label,
-		_("Helps at inserting labels to a document"));
-	gtk_container_add(GTK_CONTAINER(menu_latex_menu), menu_latex_label);
-	g_signal_connect(menu_latex_label, "activate",
-		G_CALLBACK(glatex_insert_label_activated), NULL);
-
-	menu_latex_insert_environment = gtk_menu_item_new_with_mnemonic(
-		_("Insert _Environment"));
-	ui_widget_set_tooltip_text(menu_latex_insert_environment,
-		 _("Helps at inserting an environment a document"));
-	gtk_container_add(GTK_CONTAINER(menu_latex_menu), menu_latex_insert_environment);
-	g_signal_connect(menu_latex_insert_environment, "activate",
-		G_CALLBACK(glatex_insert_environment_dialog), NULL);
-
-	menu_latex_insert_usepackage = gtk_menu_item_new_with_mnemonic(
-		_("Insert P_ackage"));
-	ui_widget_set_tooltip_text(menu_latex_insert_usepackage,
-		 _("A small dialog to insert \\usepackage{} into header of current file"));
-	gtk_container_add(GTK_CONTAINER(menu_latex_menu), menu_latex_insert_usepackage);
-	g_signal_connect(menu_latex_insert_usepackage, "activate",
-		G_CALLBACK(glatex_insert_usepackage_dialog), NULL);
-
-	menu_latex_insert_bibtex_cite =
-		gtk_menu_item_new_with_mnemonic(_("Insert B_ibTeX reference"));
-	ui_widget_set_tooltip_text(menu_latex_insert_bibtex_cite,
-		_("Helps to insert a reference out of BibTeX files"));
-	gtk_container_add(GTK_CONTAINER(menu_latex_menu), menu_latex_insert_bibtex_cite);
-	g_signal_connect(menu_latex_insert_bibtex_cite, "activate",
-		G_CALLBACK(on_insert_bibtex_dialog_activate), NULL);
-
-	menu_latex_bibtex = gtk_menu_item_new_with_mnemonic(_("_BibTeX entries"));
-	gtk_container_add(GTK_CONTAINER(menu_latex_menu), menu_latex_bibtex);
-
-	menu_latex_bibtex_submenu = gtk_menu_new();
-	gtk_menu_item_set_submenu(GTK_MENU_ITEM(menu_latex_bibtex),
-		menu_latex_bibtex_submenu);
-
-	for (i = 0; i < GLATEX_BIBTEX_N_TYPES; i++)
+	/* First we check whether the LaTeX menu entry already exists */
+	if (menu_latex == NULL)
 	{
-		tmp = NULL;
-		tmp = gtk_menu_item_new_with_mnemonic(_(glatex_bibtex_types[i].label));
-		gtk_container_add(GTK_CONTAINER(menu_latex_bibtex_submenu), tmp);
-		g_signal_connect(tmp, "activate",
-			G_CALLBACK(glatex_insert_bibtex_entry), GINT_TO_POINTER(i));
-	}
+		/* Build up menu for menubar */
+		menu_latex = gtk_menu_item_new_with_mnemonic(_("_LaTeX"));
+		gtk_menu_shell_insert(
+			menubar, menu_latex, g_list_length(menubar->children)-1);
 
-	menu_latex_format_insert = gtk_menu_item_new_with_mnemonic(_("_Format"));
-	gtk_container_add(GTK_CONTAINER(menu_latex_menu), menu_latex_format_insert);
+		menu_latex_menu = gtk_menu_new();
+		gtk_menu_item_set_submenu(GTK_MENU_ITEM(menu_latex), menu_latex_menu);
 
-	menu_latex_format_insert_submenu = gtk_menu_new();
-	gtk_menu_item_set_submenu(GTK_MENU_ITEM(menu_latex_format_insert),
-		menu_latex_format_insert_submenu);
+		/* Filling up menubar menus */
+		/* LaTeX menu */
+		menu_latex_wizard = ui_image_menu_item_new(GTK_STOCK_NEW, _("LaTeX-_Wizard"));
+		gtk_container_add(GTK_CONTAINER(menu_latex_menu), menu_latex_wizard);
+		ui_widget_set_tooltip_text(menu_latex_wizard,
+					 _("Starts a Wizard to easily create LaTeX-documents"));
 
-	for (i = 0; i < LATEX_STYLES_END; i++)
+		g_signal_connect(menu_latex_wizard, "activate",
+				 G_CALLBACK(glatex_wizard_activated), NULL);
+
+		menu_latex_menu_special_char = gtk_menu_item_new_with_mnemonic(_("I_nsert Special Character"));
+		ui_widget_set_tooltip_text(menu_latex_menu_special_char,
+					 _("Helps to use some not very common letters and signs"));
+		gtk_container_add(GTK_CONTAINER(menu_latex_menu),
+			menu_latex_menu_special_char);
+
+		menu_latex_menu_special_char_submenu = gtk_menu_new();
+		gtk_menu_item_set_submenu(GTK_MENU_ITEM(menu_latex_menu_special_char),
+			menu_latex_menu_special_char_submenu);
+		glatex_sub_menu_init(menu_latex_menu_special_char_submenu,
+			glatex_char_array, glatex_cat_names, char_insert_activated);
+
+		menu_latex_ref = gtk_menu_item_new_with_mnemonic(_("Insert _Reference"));
+		ui_widget_set_tooltip_text(menu_latex_ref,
+			_("Inserting references to the document"));
+		gtk_container_add(GTK_CONTAINER(menu_latex_menu), menu_latex_ref);
+		g_signal_connect(menu_latex_ref, "activate",
+			G_CALLBACK(glatex_insert_ref_activated), NULL);
+
+		menu_latex_label = gtk_menu_item_new_with_mnemonic(_("Insert _Label"));
+		ui_widget_set_tooltip_text(menu_latex_label,
+			_("Helps at inserting labels to a document"));
+		gtk_container_add(GTK_CONTAINER(menu_latex_menu), menu_latex_label);
+		g_signal_connect(menu_latex_label, "activate",
+			G_CALLBACK(glatex_insert_label_activated), NULL);
+
+		menu_latex_insert_environment = gtk_menu_item_new_with_mnemonic(
+			_("Insert _Environment"));
+		ui_widget_set_tooltip_text(menu_latex_insert_environment,
+			 _("Helps at inserting an environment a document"));
+		gtk_container_add(GTK_CONTAINER(menu_latex_menu), menu_latex_insert_environment);
+		g_signal_connect(menu_latex_insert_environment, "activate",
+			G_CALLBACK(glatex_insert_environment_dialog), NULL);
+
+		menu_latex_insert_usepackage = gtk_menu_item_new_with_mnemonic(
+			_("Insert P_ackage"));
+		ui_widget_set_tooltip_text(menu_latex_insert_usepackage,
+			 _("A small dialog to insert \\usepackage{} into header of current file"));
+		gtk_container_add(GTK_CONTAINER(menu_latex_menu), menu_latex_insert_usepackage);
+		g_signal_connect(menu_latex_insert_usepackage, "activate",
+			G_CALLBACK(glatex_insert_usepackage_dialog), NULL);
+
+		menu_latex_format_insert = gtk_menu_item_new_with_mnemonic(_("_Format"));
+		gtk_container_add(GTK_CONTAINER(menu_latex_menu), menu_latex_format_insert);
+
+		menu_latex_format_insert_submenu = gtk_menu_new();
+		gtk_menu_item_set_submenu(GTK_MENU_ITEM(menu_latex_format_insert),
+			menu_latex_format_insert_submenu);
+
+		for (i = 0; i < LATEX_STYLES_END; i++)
+		{
+			tmp = NULL;
+			tmp = gtk_menu_item_new_with_mnemonic(_(glatex_format_labels[i]));
+			gtk_container_add(GTK_CONTAINER(menu_latex_format_insert_submenu), tmp);
+			g_signal_connect(tmp, "activate",
+				G_CALLBACK(glatex_insert_latex_format), GINT_TO_POINTER(i));
+		}
+
+		/* Add font size menu */
+		menu_latex_fontsize = gtk_menu_item_new_with_mnemonic(_("F_ont size"));
+		gtk_container_add(GTK_CONTAINER(menu_latex_menu), menu_latex_fontsize);
+
+		menu_latex_fontsize_submenu = gtk_menu_new();
+		gtk_menu_item_set_submenu(GTK_MENU_ITEM(menu_latex_fontsize),
+			menu_latex_fontsize_submenu);
+
+		for (i = 0; i < LATEX_FONTSIZE_END; i++)
+		{
+			tmp = NULL;
+			tmp = gtk_menu_item_new_with_mnemonic(_(glatex_fontsize_labels[i]));
+			gtk_container_add(GTK_CONTAINER(menu_latex_fontsize_submenu), tmp);
+			g_signal_connect(tmp, "activate",
+				G_CALLBACK(glatex_insert_latex_fontsize), GINT_TO_POINTER(i));
+		}
+
+		/* Add menuitem for LaTeX replacement functions*/
+		menu_latex_replacement = gtk_menu_item_new_with_mnemonic(
+			_("_Special Character Replacement"));
+		menu_latex_replacement_submenu = gtk_menu_new();
+		gtk_menu_item_set_submenu(GTK_MENU_ITEM(menu_latex_replacement),
+			menu_latex_replacement_submenu);
+		gtk_container_add(GTK_CONTAINER(menu_latex_menu), menu_latex_replacement);
+
+		/* Add menuitem for bulk replacment */
+		menu_latex_replace_selection = gtk_menu_item_new_with_mnemonic(
+			_("Bulk _Replace Special Characters"));
+		ui_widget_set_tooltip_text(menu_latex_replace_selection,
+			_("_Replace selected special characters with TeX substitutes"));
+		gtk_container_add(GTK_CONTAINER(menu_latex_replacement_submenu),
+			menu_latex_replace_selection);
+		g_signal_connect(menu_latex_replace_selection, "activate",
+			G_CALLBACK(glatex_replace_special_character), NULL);
+
+		/* Add menu entry for toggling input replacment */
+		menu_latex_replace_toggle = gtk_check_menu_item_new_with_mnemonic(
+			_("Toggle _Special Character Replacement"));
+		gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM(menu_latex_replace_toggle),
+										toggle_active);
+		gtk_container_add(GTK_CONTAINER(menu_latex_replacement_submenu),
+			menu_latex_replace_toggle);
+
+		g_signal_connect(menu_latex_replace_toggle, "activate",
+						 G_CALLBACK(glatex_toggle_status), NULL);
+
+		/* Add menu entry for inserting a command */
+		menu_latex_insert_command = gtk_menu_item_new_with_mnemonic(
+			_("Insert _Command"));
+		ui_widget_set_tooltip_text(menu_latex_ref,
+			_("Inserting costumized command to document"));
+		gtk_container_add(GTK_CONTAINER(menu_latex_menu),
+			menu_latex_insert_command);
+		g_signal_connect(menu_latex_insert_command, "activate",
+			G_CALLBACK(glatex_insert_command_activated), NULL);
+
+		/* Switch document sitiveness for menu entries */
+		ui_add_document_sensitive(menu_latex_menu_special_char);
+		ui_add_document_sensitive(menu_latex_ref);
+		ui_add_document_sensitive(menu_latex_label);
+		ui_add_document_sensitive(menu_latex_format_insert);
+		ui_add_document_sensitive(menu_latex_insert_environment);
+		ui_add_document_sensitive(menu_latex_insert_usepackage);
+		ui_add_document_sensitive(menu_latex_insert_command);
+		ui_add_document_sensitive(menu_latex_fontsize);
+		ui_add_document_sensitive(menu_latex_replacement);
+
+
+		gtk_widget_show_all(menu_latex);
+	} /* only execute if menuitem "LaTeX" has not already been inserted
+	     into menubar before */
+
+	/* BibTeX menu */
+	if (menu_bibtex == NULL)
 	{
-		tmp = NULL;
-		tmp = gtk_menu_item_new_with_mnemonic(_(glatex_format_labels[i]));
-		gtk_container_add(GTK_CONTAINER(menu_latex_format_insert_submenu), tmp);
-		g_signal_connect(tmp, "activate",
-			G_CALLBACK(glatex_insert_latex_format), GINT_TO_POINTER(i));
-	}
+		menu_bibtex = gtk_menu_item_new_with_mnemonic(_("_BibTeX"));
+		gtk_menu_shell_insert(
+			menubar, menu_bibtex, g_list_length(menubar->children)-1);
 
-	/* Add font size menu */
-	menu_latex_fontsize = gtk_menu_item_new_with_mnemonic(_("F_ont size"));
-	gtk_container_add(GTK_CONTAINER(menu_latex_menu), menu_latex_fontsize);
+		menu_bibtex_menu = gtk_menu_new();
+		gtk_menu_item_set_submenu(GTK_MENU_ITEM(menu_bibtex), menu_bibtex_menu);
 
-	menu_latex_fontsize_submenu = gtk_menu_new();
-	gtk_menu_item_set_submenu(GTK_MENU_ITEM(menu_latex_fontsize),
-		menu_latex_fontsize_submenu);
+		menu_latex_insert_bibtex_cite =
+			gtk_menu_item_new_with_mnemonic(_("Insert B_ibTeX reference"));
+		ui_widget_set_tooltip_text(menu_latex_insert_bibtex_cite,
+			_("Helps to insert a reference out of BibTeX files"));
+		gtk_container_add(GTK_CONTAINER(menu_bibtex_menu), menu_latex_insert_bibtex_cite);
+		g_signal_connect(menu_latex_insert_bibtex_cite, "activate",
+			G_CALLBACK(on_insert_bibtex_dialog_activate), NULL);
 
-	for (i = 0; i < LATEX_FONTSIZE_END; i++)
-	{
-		tmp = NULL;
-		tmp = gtk_menu_item_new_with_mnemonic(_(glatex_fontsize_labels[i]));
-		gtk_container_add(GTK_CONTAINER(menu_latex_fontsize_submenu), tmp);
-		g_signal_connect(tmp, "activate",
-			G_CALLBACK(glatex_insert_latex_fontsize), GINT_TO_POINTER(i));
-	}
+		menu_latex_bibtex = gtk_menu_item_new_with_mnemonic(_("_BibTeX entries"));
+		gtk_container_add(GTK_CONTAINER(menu_bibtex_menu), menu_latex_bibtex);
 
-	/* Add menuitem for LaTeX replacement functions*/
-	menu_latex_replacement = gtk_menu_item_new_with_mnemonic(
-		_("_Special Character Replacement"));
-	menu_latex_replacement_submenu = gtk_menu_new();
-	gtk_menu_item_set_submenu(GTK_MENU_ITEM(menu_latex_replacement),
-		menu_latex_replacement_submenu);
-	gtk_container_add(GTK_CONTAINER(menu_latex_menu), menu_latex_replacement);
+		menu_latex_bibtex_submenu = gtk_menu_new();
+		gtk_menu_item_set_submenu(GTK_MENU_ITEM(menu_latex_bibtex),
+			menu_latex_bibtex_submenu);
 
-	/* Add menuitem for bulk replacment */
-	menu_latex_replace_selection = gtk_menu_item_new_with_mnemonic(
-		_("Bulk _Replace Special Characters"));
-	ui_widget_set_tooltip_text(menu_latex_replace_selection,
-		_("_Replace selected special characters with TeX substitutes"));
-	gtk_container_add(GTK_CONTAINER(menu_latex_replacement_submenu),
-		menu_latex_replace_selection);
-	g_signal_connect(menu_latex_replace_selection, "activate",
-		G_CALLBACK(glatex_replace_special_character), NULL);
+		for (i = 0; i < GLATEX_BIBTEX_N_TYPES; i++)
+		{
+			tmp = NULL;
+			tmp = gtk_menu_item_new_with_mnemonic(_(glatex_bibtex_types[i].label));
+			gtk_container_add(GTK_CONTAINER(menu_latex_bibtex_submenu), tmp);
+			g_signal_connect(tmp, "activate",
+				G_CALLBACK(glatex_insert_bibtex_entry), GINT_TO_POINTER(i));
+		}
 
-	/* Add menu entry for toggling input replacment */
-	menu_latex_replace_toggle = gtk_check_menu_item_new_with_mnemonic(
-		_("Toggle _Special Character Replacement"));
-	gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM(menu_latex_replace_toggle),
-									toggle_active);
-	gtk_container_add(GTK_CONTAINER(menu_latex_replacement_submenu),
-		menu_latex_replace_toggle);
+		/* Switch document sensitivness */
+		ui_add_document_sensitive(menu_latex_bibtex);
 
-	g_signal_connect(menu_latex_replace_toggle, "activate",
-					 G_CALLBACK(glatex_toggle_status), NULL);
-
-	/* Add menu entry for inserting a command */
-	menu_latex_insert_command = gtk_menu_item_new_with_mnemonic(
-		_("Insert _Command"));
-	ui_widget_set_tooltip_text(menu_latex_ref,
-		_("Inserting costumized command to document"));
-	gtk_container_add(GTK_CONTAINER(menu_latex_menu),
-		menu_latex_insert_command);
-	g_signal_connect(menu_latex_insert_command, "activate",
-		G_CALLBACK(glatex_insert_command_activated), NULL);
-
-	ui_add_document_sensitive(menu_latex_menu_special_char);
-	ui_add_document_sensitive(menu_latex_ref);
-	ui_add_document_sensitive(menu_latex_label);
-	ui_add_document_sensitive(menu_latex_bibtex);
-	ui_add_document_sensitive(menu_latex_format_insert);
-	ui_add_document_sensitive(menu_latex_insert_environment);
-	ui_add_document_sensitive(menu_latex_insert_usepackage);
-	ui_add_document_sensitive(menu_latex_insert_command);
-	ui_add_document_sensitive(menu_latex_fontsize);
-	ui_add_document_sensitive(menu_latex_replacement);
-
-	gtk_widget_show_all(menu_latex);
-	main_menu_item = menu_latex;
+		gtk_widget_show_all(menu_bibtex);
+	} /* Only insert BibTeX menu if not already done. */
 }
 
-
-static void
-remove_menu_from_menubar()
+/* Removes the menubar menus from menubar if requested and available */
+static void remove_menu_from_menubar(void)
 {
-	if (main_menu_item != NULL)
+	if (menu_latex != NULL)
 	{
-		gtk_widget_destroy(main_menu_item);
-		main_menu_item = NULL;
+		gtk_widget_destroy(menu_latex);
+		menu_latex = NULL;
+	}
+	if (menu_bibtex != NULL)
+	{
+		gtk_widget_destroy(menu_bibtex);
+		menu_bibtex = NULL;
 	}
-
 }
 
 
 static void
-remove_menu_from_tools_menu()
+remove_menu_from_tools_menu(void)
 {
 	if (menu_latex_toolbar_wizard != NULL)
 	{
@@ -2282,7 +2320,7 @@ remove_menu_from_tools_menu()
 
 
 static void
-add_wizard_to_tools_menu()
+add_wizard_to_tools_menu(void)
 {
 	if (menu_latex_toolbar_wizard == NULL)
 	{
@@ -2335,9 +2373,8 @@ plugin_init(G_GNUC_UNUSED GeanyData * data)
 
 	if (doc != NULL)
 	{
-		if ((glatex_add_menu_on_startup == TRUE||
-			doc->file_type->id == GEANY_FILETYPES_LATEX) &&
-			main_menu_item == NULL)
+		if (glatex_add_menu_on_startup == TRUE||
+			doc->file_type->id == GEANY_FILETYPES_LATEX)
 		{
 			add_menu_to_menubar();
 		}
@@ -2346,7 +2383,7 @@ plugin_init(G_GNUC_UNUSED GeanyData * data)
 }
 
 void
-plugin_cleanup()
+plugin_cleanup(void)
 {
 	if (glatex_toolbar != NULL)
 		gtk_widget_destroy(glatex_toolbar);
