@@ -1,7 +1,7 @@
  /*
  *      geanylatex.h
  *
- *      Copyright 2008-2011 Frank Lanitz <frank(at)frank(dot)uvena(dot)de>
+ *      Copyright 2008-2012 Frank Lanitz <frank(at)frank(dot)uvena(dot)de>
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
@@ -60,6 +60,7 @@ extern GeanyFunctions	*geany_functions;
 
 extern LaTeXWizard glatex_wizard;
 extern gboolean glatex_autobraces_active;
+extern gboolean glatex_lowercase_on_smallcaps;
 
 gint glatex_count_menu_entries(SubMenuTemplate *tmp, gint categorie);
 void glatex_wizard_activated(G_GNUC_UNUSED GtkMenuItem * menuitem,
@@ -68,7 +69,6 @@ void glatex_insert_label_activated(G_GNUC_UNUSED GtkMenuItem * menuitem,
 	 G_GNUC_UNUSED gpointer gdata);
 void glatex_insert_ref_activated(G_GNUC_UNUSED GtkMenuItem * menuitem,
 	 G_GNUC_UNUSED gpointer gdata);
-void glatex_replace_special_character(void);
 void glatex_insert_usepackage_dialog(G_GNUC_UNUSED GtkMenuItem * menuitem,
 	 G_GNUC_UNUSED gpointer gdata);
 void glatex_insert_command_activated(G_GNUC_UNUSED GtkMenuItem * menuitem,
