@@ -1,7 +1,7 @@
 /*
  *      reftex.h
  *
- *      Copyright 2009-2010 Frank Lanitz <frank(at)frank(dot)uvena(dot)de>
+ *      Copyright 2009-2012 Frank Lanitz <frank(at)frank(dot)uvena(dot)de>
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
@@ -24,12 +24,6 @@
 
 #include "geanylatex.h"
 
-typedef struct
-{
-	gchar *label_name;
-	gint page;
-	gchar *chapter;
-} LaTeXLabel;
 
 void glatex_add_Labels(GtkWidget *combobox, GSList *dir);
 
