@@ -30,6 +30,10 @@
  */
 
 
+#ifdef HAVE_CONFIG_H
+# include "config.h"
+#endif
+
 
 #include "geany.h"
 #include "plugindata.h"
