@@ -61,11 +61,6 @@ static struct {
 #define KS local_data.keybind_scripts
 
 
-
-
-extern void glspi_run_script(gchar *script_file, gint caller, GKeyFile*proj, gchar *script_dir);
-
-
 /* Called by Geany, run a script associated with a keybinding. */
 static void kb_activate(guint key_id)
 {
@@ -183,10 +178,6 @@ static void hotkey_init(void)
 
 
 
-/* Pass TRUE to create hashes, FALSE to destroy them */
-extern void glspi_set_sci_cmd_hash(gboolean create);
-extern void glspi_set_key_cmd_hash(gboolean create);
-
 static void on_doc_new(GObject *obj, GeanyDocument *doc, gpointer user_data)
 {
 	gint idx = doc->index;
@@ -322,7 +313,7 @@ static void assign_accel(GtkWidget*w, char*fn)
 
 
 
-static GtkWidget* new_menu(GtkWidget *parent, gchar* script_dir, gchar*title);
+static GtkWidget* new_menu(GtkWidget *parent, const gchar* script_dir, const gchar*title);
 
 /* GSList "for each" callback to create a menu item for each found script */
 static void init_menu(gpointer data, gpointer user_data)
@@ -363,7 +354,7 @@ static void init_menu(gpointer data, gpointer user_data)
 
 
 
-static GtkWidget* new_menu(GtkWidget *parent, gchar* script_dir, gchar*title)
+static GtkWidget* new_menu(GtkWidget *parent, const gchar* script_dir, const gchar*title)
 {
 	GSList *script_names=utils_get_file_list_full(script_dir, TRUE, TRUE, NULL);
 	if (script_names) {
