@@ -8,30 +8,8 @@
 #include "glspi.h"
 
 
-typedef gint (*KeyfileAssignFunc) (lua_State *L, GKeyFile*kf);
-
-
-
-typedef void (*GsDlgRunHook) (gboolean running, gpointer user_data);
-
-/* custom dialogs module */
-extern void glspi_init_gsdlg_module(lua_State *L, GsDlgRunHook hook, GtkWindow *toplevel);
-/* editor functions */
-extern void glspi_init_sci_funcs(lua_State *L);
-/* document functions */
-extern void glspi_init_doc_funcs(lua_State *L);
-/* basic dialog box functions */
-extern void glspi_init_dlg_funcs(lua_State *L, GsDlgRunHook hook);
-/* application functions */
-extern void glspi_init_app_funcs(lua_State *L, gchar*script_dir);
-/* menu functions */
-void glspi_init_mnu_funcs(lua_State *L);
-
 static KeyfileAssignFunc glspi_kfile_assign=NULL;
 
-void glspi_init_kfile_module(lua_State *L, KeyfileAssignFunc *func);
-
-
 
 /*
 	If a script gets caught in a tight loop and the timeout expires,
@@ -53,7 +31,7 @@ static void repaint_scintilla(void)
 
 
 /* Internal yes-or-no question box (not used by scripts) */
-static gboolean glspi_show_question(gchar*title, gchar*question, gboolean default_result)
+static gboolean glspi_show_question(const gchar*title, const gchar*question, gboolean default_result)
 {
 	GtkWidget *dialog, *yes_btn, *no_btn;
 	GtkResponseType dv, rv;
@@ -76,7 +54,7 @@ static gboolean glspi_show_question(gchar*title, gchar*question, gboolean defaul
 }
 
 
-static gboolean glspi_goto_error(gchar *fn, gint line)
+static gboolean glspi_goto_error(const gchar *fn, gint line)
 {
 	GeanyDocument *doc=document_open_file(fn, FALSE, NULL, NULL);
 	if (doc) {
@@ -103,7 +81,7 @@ static gboolean glspi_goto_error(gchar *fn, gint line)
 	give the user an option to automatically open the file and scroll to
 	the offending line.
 */
-static void glspi_script_error(gchar *script_file, const gchar *msg, gboolean need_name, gint line)
+static void glspi_script_error(const gchar *script_file, const gchar *msg, gboolean need_name, gint line)
 {
 	GtkWidget *dialog;
 	if (need_name) {
@@ -113,12 +91,12 @@ static void glspi_script_error(gchar *script_file, const gchar *msg, gboolean ne
 		gtk_message_dialog_format_secondary_text(GTK_MESSAGE_DIALOG(dialog),
 				"%s:\n%s", script_file, msg);
 	} else {
-		GtkWidget *open_btn, *cancel_btn;
+		GtkWidget *open_btn;
 		dialog=gtk_message_dialog_new(GTK_WINDOW(main_widgets->window),
 			GTK_DIALOG_DESTROY_WITH_PARENT|GTK_DIALOG_MODAL,
 			GTK_MESSAGE_ERROR, GTK_BUTTONS_NONE, _("Lua script error:"));
 		gtk_message_dialog_format_secondary_text(GTK_MESSAGE_DIALOG(dialog), "%s", msg);
-		cancel_btn=gtk_dialog_add_button(GTK_DIALOG(dialog), GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL);
+		gtk_dialog_add_button(GTK_DIALOG(dialog), GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL);
 		open_btn=gtk_dialog_add_button(GTK_DIALOG(dialog), GTK_STOCK_OPEN, GTK_RESPONSE_ACCEPT);
 		gtk_widget_grab_default(open_btn);
 	}
@@ -336,7 +314,7 @@ static gint glspi_traceback(lua_State *L)
 	The set_*_token functions assign default values for module-level variables
 */
 
-static void set_string_token(lua_State *L, gchar*name, gchar*value)
+static void set_string_token(lua_State *L, const gchar*name, const gchar*value)
 {
 	lua_getglobal(L, LUA_MODULE_NAME);
 	if (lua_istable(L, -1)) {
@@ -350,7 +328,7 @@ static void set_string_token(lua_State *L, gchar*name, gchar*value)
 
 
 
-static void set_numeric_token(lua_State *L, gchar*name, gint value)
+static void set_numeric_token(lua_State *L, const gchar*name, gint value)
 {
 	lua_getglobal(L, LUA_MODULE_NAME);
 	if (lua_istable(L, -1)) {
@@ -364,7 +342,7 @@ static void set_numeric_token(lua_State *L, gchar*name, gint value)
 
 
 
-static void set_boolean_token(lua_State *L, gchar*name, gboolean value)
+static void set_boolean_token(lua_State *L, const gchar*name, gboolean value)
 {
 	lua_getglobal(L, LUA_MODULE_NAME);
 	if (lua_istable(L, -1)) {
@@ -378,7 +356,7 @@ static void set_boolean_token(lua_State *L, gchar*name, gboolean value)
 
 
 
-static void set_keyfile_token(lua_State *L, gchar*name, GKeyFile* value)
+static void set_keyfile_token(lua_State *L, const gchar*name, GKeyFile* value)
 {
 	if (!value) {return;}
 	lua_getglobal(L, LUA_MODULE_NAME);
@@ -393,7 +371,7 @@ static void set_keyfile_token(lua_State *L, gchar*name, GKeyFile* value)
 
 
 
-static void show_error(lua_State *L, gchar *script_file)
+static void show_error(lua_State *L, const gchar *script_file)
 {
 	gint line=-1;
 	gchar *fn = glspi_get_error_info(L, &line);
@@ -413,7 +391,7 @@ static void show_error(lua_State *L, gchar *script_file)
 
 
 
-static gint glspi_init_module(lua_State *L, gchar *script_file, gint caller, GKeyFile*proj, gchar*script_dir)
+static gint glspi_init_module(lua_State *L, const gchar *script_file, gint caller, GKeyFile*proj, const gchar*script_dir)
 {
 	luaL_openlib(L, LUA_MODULE_NAME, glspi_timer_funcs, 0);
 	glspi_init_sci_funcs(L);
@@ -450,7 +428,7 @@ gint luaopen_libgeanylua(lua_State *L)
 
 
 /* Load and run the script */
-void glspi_run_script(gchar *script_file, gint caller, GKeyFile*proj, gchar *script_dir)
+void glspi_run_script(const gchar *script_file, gint caller, GKeyFile*proj, const gchar *script_dir)
 {
 	gint status;
 	lua_State *L = glspi_state_new();
