@@ -46,14 +46,14 @@ GeanyFunctions *geany_functions;
 GeanyPlugin		*geany_plugin;
 
 
-PLUGIN_VERSION_CHECK(188);
+PLUGIN_VERSION_CHECK(188)
 PLUGIN_SET_TRANSLATABLE_INFO(
 	LOCALEDIR,
 	GETTEXT_PACKAGE,
 	_("GeanyVC"),
 	_("Interface to different Version Control systems."),
 	VERSION,
-	"Yura Siamashka <yurand2@gmail.com>,\nFrank Lanitz <frank@frank.uvena.de>");
+	"Yura Siamashka <yurand2@gmail.com>,\nFrank Lanitz <frank@frank.uvena.de>")
 
 /* Some global variables */
 static gboolean set_changed_flag;
@@ -61,6 +61,7 @@ static gboolean set_add_confirmation;
 static gboolean set_maximize_commit_dialog;
 static gboolean set_external_diff;
 static gboolean set_editor_menu_entries;
+static gboolean set_menubar_entry;
 
 static gchar *config_file;
 
@@ -81,7 +82,7 @@ static GSList *VC = NULL;
 /* absolute path dirname of file */
 const gchar ABS_DIRNAME[] = "*ABS_DIRNAME*";
 /* absolute path filename of file */
-const gchar ABS_FILENAME[] = "*ABS_FILENAME*";;
+const gchar ABS_FILENAME[] = "*ABS_FILENAME*";
 
 /* path to directory from base vc directory */
 const gchar BASE_DIRNAME[] = "*BASE_DIRNAME*";
@@ -112,9 +113,9 @@ static GtkWidget *menu_item_sep = NULL;
 static GtkWidget *menu_entry = NULL;
 
 
-static void registrate();
-static void add_menuitems_to_editor_menu();
-static void remove_menuitems_from_editor_menu();
+static void registrate(void);
+static void add_menuitems_to_editor_menu(void);
+static void remove_menuitems_from_editor_menu(void);
 
 
 /* Doing some basic keybinding stuff */
@@ -375,7 +376,8 @@ get_cmd(const gchar ** argv, const gchar * dir, const gchar * filename, GSList *
 /* name should be in UTF-8, and can have a path. */
 static void
 show_output(const gchar * std_output, const gchar * name,
-	    const gchar * force_encoding, GeanyFiletype * ftype)
+	    const gchar * force_encoding, GeanyFiletype * ftype,
+	    gint line)
 {
 	gint page;
 	GtkNotebook *book;
@@ -388,6 +390,11 @@ show_output(const gchar * std_output, const gchar * name,
 		if (doc == NULL)
 		{
 			doc = document_new_file(name, ftype, std_output);
+			/* To due the given line is Scintilla's line number, but
+			 * we need the view line number in this case.  */
+			line = line + 1;
+			if (line < 1)
+				line = 1;
 		}
 		else
 		{
@@ -400,7 +407,9 @@ show_output(const gchar * std_output, const gchar * name,
 		}
 		document_set_text_changed(doc, set_changed_flag);
 		document_set_encoding(doc, (force_encoding ? force_encoding : "UTF-8"));
-		navqueue_goto_line(cur_doc, doc, 1);
+
+		navqueue_goto_line(cur_doc, doc, line);
+
 	}
 	else
 	{
@@ -626,7 +635,7 @@ vcdiff_file_activated(G_GNUC_UNUSED GtkMenuItem * menuitem, G_GNUC_UNUSED gpoint
 		else
 		{
 			name = g_strconcat(doc->file_name, ".vc.diff", NULL);
-			show_output(text, name, doc->encoding, NULL);
+			show_output(text, name, doc->encoding, NULL, 0);
 			g_free(text);
 			g_free(name);
 		}
@@ -678,7 +687,7 @@ vcdiff_dir_activated(G_GNUC_UNUSED GtkMenuItem * menuitem, gpointer data)
 	{
 		gchar *name;
 		name = g_strconcat(dir, ".vc.diff", NULL);
-		show_output(text, name, doc->encoding, NULL);
+		show_output(text, name, doc->encoding, NULL, 0);
 		g_free(text);
 		g_free(name);
 	}
@@ -705,7 +714,8 @@ vcblame_activated(G_GNUC_UNUSED GtkMenuItem * menuitem, G_GNUC_UNUSED gpointer g
 	execute_command(vc, &text, NULL, doc->file_name, VC_COMMAND_BLAME, NULL, NULL);
 	if (text)
 	{
-		show_output(text, "*VC-BLAME*", NULL, doc->file_type);
+		show_output(text, "*VC-BLAME*", NULL,
+			doc->file_type, sci_get_current_line(doc->editor->sci));
 		g_free(text);
 	}
 	else
@@ -731,7 +741,7 @@ vclog_file_activated(G_GNUC_UNUSED GtkMenuItem * menuitem, G_GNUC_UNUSED gpointe
 	execute_command(vc, &output, NULL, doc->file_name, VC_COMMAND_LOG_FILE, NULL, NULL);
 	if (output)
 	{
-		show_output(output, "*VC-LOG*", NULL, NULL);
+		show_output(output, "*VC-LOG*", NULL, NULL, 0);
 		g_free(output);
 	}
 }
@@ -755,7 +765,7 @@ vclog_dir_activated(G_GNUC_UNUSED GtkMenuItem * menuitem, G_GNUC_UNUSED gpointer
 	execute_command(vc, &text, NULL, base_name, VC_COMMAND_LOG_DIR, NULL, NULL);
 	if (text)
 	{
-		show_output(text, "*VC-LOG*", NULL, NULL);
+		show_output(text, "*VC-LOG*", NULL, NULL, 0);
 		g_free(text);
 	}
 
@@ -782,7 +792,7 @@ vclog_basedir_activated(G_GNUC_UNUSED GtkMenuItem * menuitem, G_GNUC_UNUSED gpoi
 	execute_command(vc, &text, NULL, basedir, VC_COMMAND_LOG_DIR, NULL, NULL);
 	if (text)
 	{
-		show_output(text, "*VC-LOG*", NULL, NULL);
+		show_output(text, "*VC-LOG*", NULL, NULL, 0);
 		g_free(text);
 	}
 	g_free(basedir);
@@ -813,7 +823,7 @@ vcstatus_activated(G_GNUC_UNUSED GtkMenuItem * menuitem, G_GNUC_UNUSED gpointer
 	execute_command(vc, &text, NULL, base_name, VC_COMMAND_STATUS, NULL, NULL);
 	if (text)
 	{
-		show_output(text, "*VC-STATUS*", NULL, NULL);
+		show_output(text, "*VC-STATUS*", NULL, NULL, 0);
 		g_free(text);
 	}
 
@@ -838,7 +848,7 @@ vcshow_file_activated(G_GNUC_UNUSED GtkMenuItem * menuitem, G_GNUC_UNUSED gpoint
 	{
 		gchar *name;
 		name = g_strconcat(doc->file_name, ".vc.orig", NULL);
-		show_output(output, name, doc->encoding, doc->file_type);
+		show_output(output, name, doc->encoding, doc->file_type, 0);
 		g_free(name);
 		g_free(output);
 	}
@@ -954,7 +964,7 @@ vcupdate_activated(G_GNUC_UNUSED GtkMenuItem * menuitem, G_GNUC_UNUSED gpointer
 		document_reload_file(doc, NULL);
 
 		if (NZV(text))
-			show_output(text, "*VC-UPDATE*", NULL, NULL);
+			show_output(text, "*VC-UPDATE*", NULL, NULL, 0);
 		g_free(text);
 	}
 }
@@ -1597,7 +1607,7 @@ static GtkWidget *menu_vc_commit = NULL;
 static GtkWidget *menu_vc_show_file = NULL;
 
 static void
-update_menu_items()
+update_menu_items(void)
 {
 	GeanyDocument *doc;
 
@@ -1709,6 +1719,7 @@ static struct
 	GtkWidget *cb_max_commit;
 	GtkWidget *cb_external_diff;
 	GtkWidget *cb_editor_menu_entries;
+	GtkWidget *cb_attach_to_menubar;
 	GtkWidget *cb_cvs;
 	GtkWidget *cb_git;
 	GtkWidget *cb_svn;
@@ -1737,12 +1748,14 @@ on_configure_response(G_GNUC_UNUSED GtkDialog * dialog, gint response,
 			gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(widgets.cb_confirm_add));
 		set_maximize_commit_dialog =
 			gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(widgets.cb_max_commit));
-
+		
 		set_external_diff =
 			gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(widgets.cb_external_diff));
 
 		set_editor_menu_entries =
 			gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(widgets.cb_editor_menu_entries));
+		set_menubar_entry =
+			gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(widgets.cb_attach_to_menubar));
 
 		enable_cvs = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(widgets.cb_cvs));
 		enable_git = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(widgets.cb_git));
@@ -1764,6 +1777,7 @@ on_configure_response(G_GNUC_UNUSED GtkDialog * dialog, gint response,
 		g_key_file_set_boolean(config, "VC", "set_maximize_commit_dialog",
 				       set_maximize_commit_dialog);
 		g_key_file_set_boolean(config, "VC", "set_editor_menu_entries", set_editor_menu_entries);
+		g_key_file_set_boolean(config, "VC", "attach_to_menubar", set_menubar_entry);
 
 		g_key_file_set_boolean(config, "VC", "enable_cvs", enable_cvs);
 		g_key_file_set_boolean(config, "VC", "enable_git", enable_git);
@@ -1859,6 +1873,16 @@ plugin_configure(GtkDialog * dialog)
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(widgets.cb_editor_menu_entries), set_editor_menu_entries);
 	gtk_box_pack_start(GTK_BOX(vbox), widgets.cb_editor_menu_entries, TRUE, FALSE, 2);
 
+	widgets.cb_attach_to_menubar = gtk_check_button_new_with_label(_("Attach menu to menubar"));
+	ui_widget_set_tooltip_text(widgets.cb_editor_menu_entries,
+			     _("Whether menu for this plugin are getting placed either "
+			       "inside tools menu or directly inside Geany's menubar."
+			       "Will take in account after next start of GeanyVC"));
+	gtk_button_set_focus_on_click(GTK_BUTTON(widgets.cb_attach_to_menubar), FALSE);
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(widgets.cb_attach_to_menubar), 
+		set_menubar_entry);
+	gtk_box_pack_start(GTK_BOX(vbox), widgets.cb_attach_to_menubar, TRUE, FALSE, 2);
+
 	widgets.cb_cvs = gtk_check_button_new_with_label(_("Enable CVS"));
 	gtk_button_set_focus_on_click(GTK_BUTTON(widgets.cb_cvs), FALSE);
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(widgets.cb_cvs), enable_cvs);
@@ -1907,7 +1931,7 @@ plugin_configure(GtkDialog * dialog)
 }
 
 static void
-load_config()
+load_config(void)
 {
 #ifdef USE_GTKSPELL
 	GError *error = NULL;
@@ -1939,6 +1963,8 @@ load_config()
 		TRUE);
 	enable_hg = utils_get_setting_boolean(config, "VC", "enable_hg",
 		TRUE);
+	set_menubar_entry = utils_get_setting_boolean(config, "VC", "attach_to_menubar",
+		FALSE);
 
 #ifdef USE_GTKSPELL
 	lang = g_key_file_get_string(config, "VC", "spellchecking_language", &error);
@@ -1955,7 +1981,7 @@ load_config()
 }
 
 static void
-registrate()
+registrate(void)
 {
 	gchar *path;
 	if (VC)
@@ -2135,7 +2161,7 @@ do_basedir_menu(GtkWidget ** parent_menu)
 }
 
 static void
-add_menuitems_to_editor_menu()
+add_menuitems_to_editor_menu(void)
 {
 	/* Add file menu also to editor menu (at mouse cursor) */
 	if (set_editor_menu_entries == TRUE && editor_menu_vc == NULL)
@@ -2160,7 +2186,7 @@ add_menuitems_to_editor_menu()
 }
 
 static void
-remove_menuitems_from_editor_menu()
+remove_menuitems_from_editor_menu(void)
 {
 	if (editor_menu_vc != NULL)
 	{
@@ -2215,7 +2241,7 @@ plugin_init(G_GNUC_UNUSED GeanyData * data)
 	GtkWidget *menu_vc_file = NULL;
 	GtkWidget *menu_vc_dir = NULL;
 	GtkWidget *menu_vc_basedir = NULL;
-
+	
 	config_file =
 		g_strconcat(geany->app->configdir, G_DIR_SEPARATOR_S, "plugins", G_DIR_SEPARATOR_S,
 			    "VC", G_DIR_SEPARATOR_S, "VC.conf", NULL);
@@ -2223,8 +2249,23 @@ plugin_init(G_GNUC_UNUSED GeanyData * data)
 	load_config();
 	registrate();
 
-	menu_vc = gtk_image_menu_item_new_with_mnemonic(_("_VC"));
-	gtk_container_add(GTK_CONTAINER(geany->main_widgets->tools_menu), menu_vc);
+
+	if (set_menubar_entry == TRUE)
+	{
+		GtkMenuShell *menubar;
+		
+		menubar = GTK_MENU_SHELL(
+				ui_lookup_widget(geany->main_widgets->window, "menubar1"));
+
+		menu_vc = gtk_menu_item_new_with_mnemonic(_("_VC"));
+		gtk_menu_shell_insert(
+			menubar, menu_vc, g_list_length(menubar->children)-1);
+	}
+	else
+	{
+		menu_vc = gtk_image_menu_item_new_with_mnemonic(_("_Version Control"));
+		gtk_container_add(GTK_CONTAINER(geany->main_widgets->tools_menu), menu_vc);
+	}
 
 	g_signal_connect(menu_vc, "activate", G_CALLBACK(update_menu_items), NULL);
 
@@ -2279,7 +2320,7 @@ plugin_init(G_GNUC_UNUSED GeanyData * data)
 
 /* Called by Geany before unloading the plugin. */
 void
-plugin_cleanup()
+plugin_cleanup(void)
 {
 	remove_menuitems_from_editor_menu();
 	gtk_widget_destroy(menu_entry);
