@@ -42,70 +42,70 @@ static const gchar *SVK_CMD_UPDATE[] = { "svk", "up", NULL };
 
 static const VC_COMMAND commands[] = {
 	{
-	 .startdir = VC_COMMAND_STARTDIR_FILE,
-	 .command = SVK_CMD_DIFF_FILE,
-	 .env = NULL,
-	 .function = NULL},
+		VC_COMMAND_STARTDIR_FILE,
+		SVK_CMD_DIFF_FILE,
+		NULL,
+		NULL},
 	{
-	 .startdir = VC_COMMAND_STARTDIR_FILE,
-	 .command = SVK_CMD_DIFF_DIR,
-	 .env = NULL,
-	 .function = NULL},
+		VC_COMMAND_STARTDIR_FILE,
+		SVK_CMD_DIFF_DIR,
+		NULL,
+		NULL},
 	{
-	 .startdir = VC_COMMAND_STARTDIR_FILE,
-	 .command = SVK_CMD_REVERT_FILE,
-	 .env = NULL,
-	 .function = NULL},
+		VC_COMMAND_STARTDIR_FILE,
+		SVK_CMD_REVERT_FILE,
+		NULL,
+		NULL},
 	{
-	 .startdir = VC_COMMAND_STARTDIR_BASE,
-	 .command = SVK_CMD_REVERT_DIR,
-	 .env = NULL,
-	 .function = NULL},
+		VC_COMMAND_STARTDIR_BASE,
+		SVK_CMD_REVERT_DIR,
+		NULL,
+		NULL},
 	{
-	 .startdir = VC_COMMAND_STARTDIR_FILE,
-	 .command = SVK_CMD_STATUS,
-	 .env = NULL,
-	 .function = NULL},
+		VC_COMMAND_STARTDIR_FILE,
+		SVK_CMD_STATUS,
+		NULL,
+		NULL},
 	{
-	 .startdir = VC_COMMAND_STARTDIR_FILE,
-	 .command = SVK_CMD_ADD,
-	 .env = NULL,
-	 .function = NULL},
+		VC_COMMAND_STARTDIR_FILE,
+		SVK_CMD_ADD,
+		NULL,
+		NULL},
 	{
-	 .startdir = VC_COMMAND_STARTDIR_FILE,
-	 .command = SVK_CMD_REMOVE,
-	 .env = NULL,
-	 .function = NULL},
+		VC_COMMAND_STARTDIR_FILE,
+		SVK_CMD_REMOVE,
+		NULL,
+		NULL},
 	{
-	 .startdir = VC_COMMAND_STARTDIR_FILE,
-	 .command = SVK_CMD_LOG_FILE,
-	 .env = NULL,
-	 .function = NULL},
+		VC_COMMAND_STARTDIR_FILE,
+		SVK_CMD_LOG_FILE,
+		NULL,
+		NULL},
 	{
-	 .startdir = VC_COMMAND_STARTDIR_FILE,
-	 .command = SVK_CMD_LOG_DIR,
-	 .env = NULL,
-	 .function = NULL},
+		VC_COMMAND_STARTDIR_FILE,
+		SVK_CMD_LOG_DIR,
+		NULL,
+		NULL},
 	{
-	 .startdir = VC_COMMAND_STARTDIR_FILE,
-	 .command = SVK_CMD_COMMIT,
-	 .env = NULL,
-	 .function = NULL},
+		VC_COMMAND_STARTDIR_FILE,
+		SVK_CMD_COMMIT,
+		NULL,
+		NULL},
 	{
-	 .startdir = VC_COMMAND_STARTDIR_FILE,
-	 .command = SVK_CMD_BLAME,
-	 .env = NULL,
-	 .function = NULL},
+		VC_COMMAND_STARTDIR_FILE,
+		SVK_CMD_BLAME,
+		NULL,
+		NULL},
 	{
-	 .startdir = VC_COMMAND_STARTDIR_FILE,
-	 .command = SVK_CMD_SHOW,
-	 .env = NULL,
-	 .function = NULL},
+		VC_COMMAND_STARTDIR_FILE,
+		SVK_CMD_SHOW,
+		NULL,
+		NULL},
 	{
-	 .startdir = VC_COMMAND_STARTDIR_BASE,
-	 .command = SVK_CMD_UPDATE,
-	 .env = NULL,
-	 .function = NULL}
+		VC_COMMAND_STARTDIR_BASE,
+		SVK_CMD_UPDATE,
+		NULL,
+		NULL}
 };
 
 
@@ -252,9 +252,9 @@ get_commit_files_svk(const gchar * dir)
 }
 
 VC_RECORD VC_SVK = {
-	.commands = commands,
-	.program = "svk",
-	.get_base_dir = get_base_dir,
-	.in_vc = in_vc_svk,
-	.get_commit_files = get_commit_files_svk,
+	commands,
+	"svk",
+	get_base_dir,
+	in_vc_svk,
+	get_commit_files_svk,
 };
