@@ -44,70 +44,70 @@ static const gchar *SVN_CMD_UPDATE[] = { "svn", "up", NULL };
 
 static const VC_COMMAND commands[] = {
 	{
-	 .startdir = VC_COMMAND_STARTDIR_BASE,
-	 .command = SVN_CMD_DIFF_FILE,
-	 .env = NULL,
-	 .function = NULL},
+		VC_COMMAND_STARTDIR_BASE,
+		SVN_CMD_DIFF_FILE,
+		NULL,
+		NULL},
 	{
-	 .startdir = VC_COMMAND_STARTDIR_BASE,
-	 .command = SVN_CMD_DIFF_DIR,
-	 .env = NULL,
-	 .function = NULL},
+		VC_COMMAND_STARTDIR_BASE,
+		SVN_CMD_DIFF_DIR,
+		NULL,
+		NULL},
 	{
-	 .startdir = VC_COMMAND_STARTDIR_FILE,
-	 .command = SVN_CMD_REVERT_FILE,
-	 .env = NULL,
-	 .function = NULL},
+		VC_COMMAND_STARTDIR_FILE,
+		SVN_CMD_REVERT_FILE,
+		NULL,
+		NULL},
 	{
-	 .startdir = VC_COMMAND_STARTDIR_BASE,
-	 .command = SVN_CMD_REVERT_DIR,
-	 .env = NULL,
-	 .function = NULL},
+		VC_COMMAND_STARTDIR_BASE,
+		SVN_CMD_REVERT_DIR,
+		NULL,
+		NULL},
 	{
-	 .startdir = VC_COMMAND_STARTDIR_FILE,
-	 .command = SVN_CMD_STATUS,
-	 .env = NULL,
-	 .function = NULL},
+		VC_COMMAND_STARTDIR_FILE,
+		SVN_CMD_STATUS,
+		NULL,
+		NULL},
 	{
-	 .startdir = VC_COMMAND_STARTDIR_FILE,
-	 .command = SVN_CMD_ADD,
-	 .env = NULL,
-	 .function = NULL},
+		VC_COMMAND_STARTDIR_FILE,
+		SVN_CMD_ADD,
+		NULL,
+		NULL},
 	{
-	 .startdir = VC_COMMAND_STARTDIR_FILE,
-	 .command = SVN_CMD_REMOVE,
-	 .env = NULL,
-	 .function = NULL},
+		VC_COMMAND_STARTDIR_FILE,
+		SVN_CMD_REMOVE,
+		NULL,
+		NULL},
 	{
-	 .startdir = VC_COMMAND_STARTDIR_FILE,
-	 .command = SVN_CMD_LOG_FILE,
-	 .env = NULL,
-	 .function = NULL},
+		VC_COMMAND_STARTDIR_FILE,
+		SVN_CMD_LOG_FILE,
+		NULL,
+		NULL},
 	{
-	 .startdir = VC_COMMAND_STARTDIR_FILE,
-	 .command = SVN_CMD_LOG_DIR,
-	 .env = NULL,
-	 .function = NULL},
+		VC_COMMAND_STARTDIR_FILE,
+		SVN_CMD_LOG_DIR,
+		NULL,
+		NULL},
 	{
-	 .startdir = VC_COMMAND_STARTDIR_FILE,
-	 .command = SVN_CMD_COMMIT,
-	 .env = NULL,
-	 .function = NULL},
+		VC_COMMAND_STARTDIR_FILE,
+		SVN_CMD_COMMIT,
+		NULL,
+		NULL},
 	{
-	 .startdir = VC_COMMAND_STARTDIR_FILE,
-	 .command = SVN_CMD_BLAME,
-	 .env = NULL,
-	 .function = NULL},
+		VC_COMMAND_STARTDIR_FILE,
+		SVN_CMD_BLAME,
+		NULL,
+		NULL},
 	{
-	 .startdir = VC_COMMAND_STARTDIR_FILE,
-	 .command = SVN_CMD_SHOW,
-	 .env = NULL,
-	 .function = NULL},
+		VC_COMMAND_STARTDIR_FILE,
+		SVN_CMD_SHOW,
+		NULL,
+		NULL},
 	{
-	 .startdir = VC_COMMAND_STARTDIR_BASE,
-	 .command = SVN_CMD_UPDATE,
-	 .env = NULL,
-	 .function = NULL}
+		VC_COMMAND_STARTDIR_BASE,
+		SVN_CMD_UPDATE,
+		NULL,
+		NULL}
 };
 
 static gchar *
@@ -166,7 +166,6 @@ get_base_dir(const gchar * path)
 static gboolean
 in_vc_svn(const gchar * filename)
 {
-	gint exit_code;
 	const gchar *argv[] = { "svn", "info", "--non-interactive", NULL, NULL };
 	gchar *dir;
 	gchar *base_name;
@@ -183,8 +182,8 @@ in_vc_svn(const gchar * filename)
 	base_name = g_path_get_basename(filename);
 	argv[3] = base_name;
 
-	exit_code = execute_custom_command(dir, (const gchar **) argv, NULL, &std_output, NULL,
-					   dir, NULL, NULL);
+	execute_custom_command(dir, (const gchar **) argv, NULL, &std_output, NULL,
+			       dir, NULL, NULL);
 	if (NZV(std_output))
 	{
 		ret = TRUE;
@@ -293,9 +292,9 @@ get_commit_files_svn(const gchar * dir)
 }
 
 VC_RECORD VC_SVN = {
-	.commands = commands,
-	.program = "svn",
-	.get_base_dir = get_base_dir,
-	.in_vc = in_vc_svn,
-	.get_commit_files = get_commit_files_svn,
+	commands,
+	"svn",
+	get_base_dir,
+	in_vc_svn,
+	get_commit_files_svn,
 };
