@@ -14,6 +14,7 @@
 #include <fcntl.h>
 #include <glib.h>
 #include <glib/gstdio.h>
+#include <gdk/gdkkeysyms.h>
 
 #include "geany.h"
 #include "geanyplugin.h"
@@ -56,12 +57,14 @@ static gboolean 			flag_on_expand_refresh 		= FALSE;
  *  CONFIG VARS
  * ------------------ */
 
-static gchar 				*CONFIG_FILE 				= NULL;
 #ifdef G_OS_WIN32
-static gchar 				*CONFIG_OPEN_EXTERNAL_CMD 	= "nautilus '%d'";
+# define CONFIG_OPEN_EXTERNAL_CMD_DEFAULT "nautilus '%d'"
 #else
-static gchar 				*CONFIG_OPEN_EXTERNAL_CMD 	= "explorer '%d'";
+# define CONFIG_OPEN_EXTERNAL_CMD_DEFAULT "explorer '%d'"
 #endif
+
+static gchar 				*CONFIG_FILE 				= NULL;
+static gchar 				*CONFIG_OPEN_EXTERNAL_CMD 	= NULL;
 static gboolean 			CONFIG_REVERSE_FILTER 		= FALSE;
 static gboolean 			CONFIG_ONE_CLICK_CHDOC 		= FALSE;
 static gboolean 			CONFIG_SHOW_HIDDEN_FILES 	= FALSE;
@@ -100,6 +103,8 @@ enum
 	KB_FOCUS_FILE_LIST,
 	KB_FOCUS_PATH_ENTRY,
 	KB_RENAME_OBJECT,
+	KB_CREATE_FILE,
+	KB_CREATE_DIR,
 	KB_REFRESH,
 	KB_COUNT
 };
@@ -143,12 +148,13 @@ _gtk_cell_layout_get_cells(GtkTreeViewColumn *column)
 
 static void 	project_change_cb(G_GNUC_UNUSED GObject *obj, G_GNUC_UNUSED GKeyFile *config, G_GNUC_UNUSED gpointer data);
 static void 	treebrowser_browse(gchar *directory, gpointer parent);
-static void 	treebrowser_bookmarks_set_state();
-static void 	treebrowser_load_bookmarks();
+static void 	treebrowser_bookmarks_set_state(void);
+static void 	treebrowser_load_bookmarks(void);
 static void 	gtk_tree_store_iter_clear_nodes(gpointer iter, gboolean delete_root);
-static void 	treebrowser_rename_current();
-static void 	load_settings();
-static gboolean save_settings();
+static void 	treebrowser_rename_current(void);
+static void 	on_menu_create_new_object(GtkMenuItem *menuitem, const gchar *type);
+static void 	load_settings(void);
+static gboolean save_settings(void);
 
 
 /* ------------------
@@ -231,7 +237,7 @@ utils_pixbuf_from_path(gchar *path)
 static gchar*
 path_is_in_dir(gchar* src, gchar* find)
 {
-	int i = 0;
+	guint i = 0;
 
 	gchar *diffed_path = NULL, *tmp = NULL;
 	gchar **src_segments = NULL, **find_segments = NULL;
@@ -332,13 +338,16 @@ win32_check_hidden(const gchar *filename)
 static gboolean
 check_hidden(const gchar *filename)
 {
+	gsize len;
 	const gchar *base_name = NULL;
 	base_name = g_path_get_basename(filename);
-	gsize len;
 
 	if (! NZV(base_name))
 		return FALSE;
 
+	if (CONFIG_SHOW_HIDDEN_FILES)
+		return FALSE;
+
 #ifdef G_OS_WIN32
 	if (win32_check_hidden(filename))
 		return TRUE;
@@ -355,7 +364,7 @@ check_hidden(const gchar *filename)
 }
 
 static gchar*
-get_default_dir()
+get_default_dir(void)
 {
 	gchar 			*dir;
 	GeanyProject 	*project 	= geany->app->project;
@@ -385,7 +394,7 @@ get_default_dir()
 }
 
 static gchar *
-get_terminal()
+get_terminal(void)
 {
 	gchar 		*terminal;
 #ifdef G_OS_WIN32
@@ -429,23 +438,30 @@ treebrowser_checkdir(gchar *directory)
 }
 
 static void
-treebrowser_chroot(gchar *directory)
+treebrowser_chroot(const gchar *dir)
 {
-	if (g_str_has_suffix(directory, G_DIR_SEPARATOR_S))
-		g_strlcpy(directory, directory, strlen(directory));
+	gchar *directory;
+
+	if (g_str_has_suffix(dir, G_DIR_SEPARATOR_S))
+		directory = g_strndup(dir, strlen(dir)-1);
+	else
+		directory = g_strdup(dir);
 
 	gtk_entry_set_text(GTK_ENTRY(addressbar), directory);
 
 	if (!directory || strlen(directory) == 0)
-		directory = G_DIR_SEPARATOR_S;
+		setptr(directory, g_strdup(G_DIR_SEPARATOR_S));
 
 	if (! treebrowser_checkdir(directory))
+	{
+		g_free(directory);
 		return;
+	}
 
 	treebrowser_bookmarks_set_state();
 
 	gtk_tree_store_clear(treestore);
-	setptr(addressbar_last_address, g_strdup(directory));
+	setptr(addressbar_last_address, directory);
 
 	treebrowser_browse(addressbar_last_address, NULL);
 	treebrowser_load_bookmarks();
@@ -480,7 +496,8 @@ treebrowser_browse(gchar *directory, gpointer parent)
 		treebrowser_bookmarks_set_state();
 	}
 
-	gtk_tree_store_iter_clear_nodes(parent, FALSE);
+	if (parent)
+		gtk_tree_store_iter_clear_nodes(parent, FALSE);
 
 	list = utils_get_file_list(directory, NULL, NULL);
 	if (list != NULL)
@@ -568,7 +585,7 @@ treebrowser_browse(gchar *directory, gpointer parent)
 }
 
 static void
-treebrowser_bookmarks_set_state()
+treebrowser_bookmarks_set_state(void)
 {
 	if (gtk_tree_store_iter_is_valid(treestore, &bookmarks_iter))
 		bookmarks_expanded = tree_view_row_expanded_iter(GTK_TREE_VIEW(treeview), &bookmarks_iter);
@@ -577,7 +594,7 @@ treebrowser_bookmarks_set_state()
 }
 
 static void
-treebrowser_load_bookmarks()
+treebrowser_load_bookmarks(void)
 {
 	gchar 		*bookmarks;
 	gchar 		*contents, *path_full;
@@ -637,13 +654,16 @@ treebrowser_load_bookmarks()
 			{
 				if (g_file_test(path_full, G_FILE_TEST_EXISTS | G_FILE_TEST_IS_DIR))
 				{
+					gchar *file_name = g_path_get_basename(path_full);
+
 					gtk_tree_store_append(treestore, &iter, &bookmarks_iter);
 					icon = CONFIG_SHOW_ICONS ? utils_pixbuf_from_stock(GTK_STOCK_DIRECTORY) : NULL;
 					gtk_tree_store_set(treestore, &iter,
 												TREEBROWSER_COLUMN_ICON, 	icon,
-												TREEBROWSER_COLUMN_NAME, 	g_basename(path_full),
+												TREEBROWSER_COLUMN_NAME, 	file_name,
 												TREEBROWSER_COLUMN_URI, 	path_full,
 												-1);
+					g_free(file_name);
 					if (icon)
 						g_object_unref(icon);
 					gtk_tree_store_append(treestore, &iter, &iter);
@@ -676,30 +696,31 @@ treebrowser_search(gchar *uri, gpointer parent)
 	GtkTreePath 	*path;
 	gchar 			*uri_current;
 
-	gtk_tree_model_iter_children(GTK_TREE_MODEL(treestore), &iter, parent);
-
-	do
+	if (gtk_tree_model_iter_children(GTK_TREE_MODEL(treestore), &iter, parent))
 	{
-		if (gtk_tree_model_iter_has_child(GTK_TREE_MODEL(treestore), &iter))
-			if (treebrowser_search(uri, &iter))
-				return TRUE;
-
-		gtk_tree_model_get(GTK_TREE_MODEL(treestore), &iter, TREEBROWSER_COLUMN_URI, &uri_current, -1);
-
-		if (utils_str_equal(uri, uri_current) == TRUE)
+		do
 		{
-			path = gtk_tree_model_get_path(GTK_TREE_MODEL(treestore), &iter);
-			gtk_tree_view_expand_to_path(GTK_TREE_VIEW(treeview), path);
-			gtk_tree_view_scroll_to_cell(GTK_TREE_VIEW(treeview), path, TREEBROWSER_COLUMN_ICON, FALSE, 0, 0);
-			gtk_tree_view_set_cursor(GTK_TREE_VIEW(treeview), path, treeview_column_text, FALSE);
-			gtk_tree_path_free(path);
-			g_free(uri_current);
-			return TRUE;
-		}
-		else
-			g_free(uri_current);
+			if (gtk_tree_model_iter_has_child(GTK_TREE_MODEL(treestore), &iter))
+				if (treebrowser_search(uri, &iter))
+					return TRUE;
 
-	} while(gtk_tree_model_iter_next(GTK_TREE_MODEL(treestore), &iter));
+			gtk_tree_model_get(GTK_TREE_MODEL(treestore), &iter, TREEBROWSER_COLUMN_URI, &uri_current, -1);
+
+			if (utils_str_equal(uri, uri_current) == TRUE)
+			{
+				path = gtk_tree_model_get_path(GTK_TREE_MODEL(treestore), &iter);
+				gtk_tree_view_expand_to_path(GTK_TREE_VIEW(treeview), path);
+				gtk_tree_view_scroll_to_cell(GTK_TREE_VIEW(treeview), path, TREEBROWSER_COLUMN_ICON, FALSE, 0, 0);
+				gtk_tree_view_set_cursor(GTK_TREE_VIEW(treeview), path, treeview_column_text, FALSE);
+				gtk_tree_path_free(path);
+				g_free(uri_current);
+				return TRUE;
+			}
+			else
+				g_free(uri_current);
+
+		} while (gtk_tree_model_iter_next(GTK_TREE_MODEL(treestore), &iter));
+	}
 
 	return FALSE;
 }
@@ -770,11 +791,10 @@ gtk_tree_store_iter_clear_nodes(gpointer iter, gboolean delete_root)
 {
 	GtkTreeIter i;
 
-	while (gtk_tree_model_iter_children(GTK_TREE_MODEL(treestore), &i, iter))
+	if (gtk_tree_model_iter_children(GTK_TREE_MODEL(treestore), &i, iter))
 	{
-		if (gtk_tree_model_iter_has_child(GTK_TREE_MODEL(treestore), &i))
-			gtk_tree_store_iter_clear_nodes(&i, TRUE);
-		gtk_tree_store_remove(GTK_TREE_STORE(treestore), &i);
+		while (gtk_tree_store_remove(GTK_TREE_STORE(treestore), &i))
+			/* do nothing */;
 	}
 	if (delete_root)
 		gtk_tree_store_remove(GTK_TREE_STORE(treestore), iter);
@@ -783,9 +803,9 @@ gtk_tree_store_iter_clear_nodes(gpointer iter, gboolean delete_root)
 static gboolean
 treebrowser_expand_to_path(gchar* root, gchar* find)
 {
-	int i = 0, j = 0;
+	guint i = 0;
 	gboolean founded = FALSE, global_founded = FALSE;
-	gchar *new = "";
+	gchar *new = NULL;
 	gchar **root_segments = NULL, **find_segments = NULL;
 	guint root_segments_n = 0, find_segments_n = 0;
 
@@ -798,7 +818,7 @@ treebrowser_expand_to_path(gchar* root, gchar* find)
 
 	for (i = 1; i<=find_segments_n; i++)
 	{
-		new = g_strconcat(new, G_DIR_SEPARATOR_S, find_segments[i], NULL);
+		new = g_strconcat(new ? new : "", G_DIR_SEPARATOR_S, find_segments[i], NULL);
 
 		if (founded)
 		{
@@ -818,7 +838,7 @@ treebrowser_expand_to_path(gchar* root, gchar* find)
 }
 
 static gboolean
-treebrowser_track_current()
+treebrowser_track_current(void)
 {
 
 	GeanyDocument	*doc 		= document_get_current();
@@ -888,7 +908,7 @@ treebrowser_iter_rename(gpointer iter)
 }
 
 static void
-treebrowser_rename_current()
+treebrowser_rename_current(void)
 {
 	GtkTreeSelection 	*selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(treeview));
 	GtkTreeIter 		iter;
@@ -900,6 +920,13 @@ treebrowser_rename_current()
 	}
 }
 
+static void
+treebrowser_create_new_current(const gchar *type)
+{
+	on_menu_create_new_object(NULL, type);
+}
+
+
 /* ------------------
  * RIGHTCLICK MENU EVENTS
  * ------------------*/
@@ -983,24 +1010,27 @@ on_menu_find_in_files(GtkMenuItem *menuitem, gchar *uri)
 }
 
 static void
-on_menu_create_new_object(GtkMenuItem *menuitem, gchar *type)
+on_menu_create_new_object(GtkMenuItem *menuitem, const gchar *type)
 {
 	GtkTreeSelection 	*selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(treeview));
-	GtkTreeIter 		iter;
+	GtkTreeIter 		iter, iter_parent;
 	GtkTreeModel 		*model;
 	gchar 				*uri, *uri_new = NULL;
-	GtkTreePath 		*path_parent;
 	gboolean 			refresh_root = FALSE;
 
 	if (gtk_tree_selection_get_selected(selection, &model, &iter))
 	{
 		gtk_tree_model_get(model, &iter, TREEBROWSER_COLUMN_URI, &uri, -1);
+		/* If not a directory, find parent directory */
 		if (! g_file_test(uri, G_FILE_TEST_IS_DIR))
 		{
-			setptr(uri, g_path_get_dirname(uri));
-			path_parent = gtk_tree_model_get_path(GTK_TREE_MODEL(treestore), &iter);
-			if (gtk_tree_path_up(path_parent) &&
-				gtk_tree_model_get_iter(GTK_TREE_MODEL(treestore), &iter, path_parent));
+			if (gtk_tree_model_iter_parent(GTK_TREE_MODEL(treestore), &iter_parent, &iter))
+			{
+				iter = iter_parent;
+				/* Set URI from parent iter */
+				g_free(uri);
+				gtk_tree_model_get(model, &iter_parent, TREEBROWSER_COLUMN_URI, &uri, -1);
+			}
 			else
 				refresh_root = TRUE;
 		}
@@ -1029,7 +1059,7 @@ on_menu_create_new_object(GtkMenuItem *menuitem, gchar *type)
 			if (utils_str_equal(type, "directory"))
 				creation_success = (g_mkdir(uri_new, 0755) == 0);
 			else
-				creation_success = (g_creat(uri_new, 0755) != -1);
+				creation_success = (g_creat(uri_new, 0644) != -1);
 
 			if (creation_success)
 			{
@@ -1054,9 +1084,8 @@ on_menu_delete(GtkMenuItem *menuitem, gpointer *user_data)
 {
 
 	GtkTreeSelection 	*selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(treeview));
-	GtkTreeIter 		iter;
+	GtkTreeIter 		iter, iter_parent;
 	GtkTreeModel 		*model;
-	GtkTreePath 		*path_parent;
 	gchar 				*uri, *uri_parent;
 
 	if (! gtk_tree_selection_get_selected(selection, &model, &iter))
@@ -1071,17 +1100,10 @@ on_menu_delete(GtkMenuItem *menuitem, gpointer *user_data)
 
 		uri_parent = g_path_get_dirname(uri);
 		fs_remove(uri, TRUE);
-		path_parent = gtk_tree_model_get_path(GTK_TREE_MODEL(treestore), &iter);
-		if (gtk_tree_path_up(path_parent))
-		{
-			if (gtk_tree_model_get_iter(GTK_TREE_MODEL(treestore), &iter, path_parent))
-				treebrowser_browse(uri_parent, &iter);
-			else
-				treebrowser_browse(uri_parent, NULL);
-		}
+		if (gtk_tree_model_iter_parent(GTK_TREE_MODEL(treestore), &iter_parent, &iter))
+			treebrowser_browse(uri_parent, &iter_parent);
 		else
 			treebrowser_browse(uri_parent, NULL);
-		gtk_tree_path_free(path_parent);
 		g_free(uri_parent);
 	}
 	g_free(uri);
@@ -1129,16 +1151,16 @@ static void
 on_menu_close_children(GtkMenuItem *menuitem, gchar *uri)
 {
 	guint i;
-	int uri_len = strlen(uri);
+	size_t uri_len = strlen(uri);
 	for (i=0; i < GEANY(documents_array)->len; i++)
 	{
 		if (documents[i]->is_valid)
 		{
 			/* the docuemnt filename shoudl always be longer than the uri when closing children
 			 * Compare the beginingin of the filename string to see if it matchs the uri*/
-			if (strlen(documents[i]->file_name) > uri_len )
+			if (strlen(documents[i]->file_name) > uri_len)
 			{
-				if (strncmp(uri,documents[i]->file_name, uri_len)==0)
+				if (strncmp(uri, documents[i]->file_name, uri_len)==0)
 					document_close(documents[i]);
 			}
 		}
@@ -1175,7 +1197,7 @@ on_menu_show_bars(GtkMenuItem *menuitem, gpointer *user_data)
 }
 
 static GtkWidget*
-create_popup_menu(gchar *name, gchar *uri)
+create_popup_menu(const gchar *name, const gchar *uri)
 {
 	GtkWidget *item, *menu = gtk_menu_new();
 
@@ -1193,16 +1215,16 @@ create_popup_menu(gchar *name, gchar *uri)
 
 	item = ui_image_menu_item_new(GTK_STOCK_OPEN, _("Open externally"));
 	gtk_container_add(GTK_CONTAINER(menu), item);
-	g_signal_connect(item, "activate", G_CALLBACK(on_menu_open_externally), uri);
+	g_signal_connect_data(item, "activate", G_CALLBACK(on_menu_open_externally), g_strdup(uri), (GClosureNotify)g_free, 0);
 	gtk_widget_set_sensitive(item, is_exists);
 
 	item = ui_image_menu_item_new("utilities-terminal", _("Open Terminal"));
 	gtk_container_add(GTK_CONTAINER(menu), item);
-	g_signal_connect(item, "activate", G_CALLBACK(on_menu_open_terminal), uri);
+	g_signal_connect_data(item, "activate", G_CALLBACK(on_menu_open_terminal), g_strdup(uri), (GClosureNotify)g_free, 0);
 
 	item = ui_image_menu_item_new(GTK_STOCK_GOTO_TOP, _("Set as root"));
 	gtk_container_add(GTK_CONTAINER(menu), item);
-	g_signal_connect(item, "activate", G_CALLBACK(on_menu_set_as_root), uri);
+	g_signal_connect_data(item, "activate", G_CALLBACK(on_menu_set_as_root), g_strdup(uri), (GClosureNotify)g_free, 0);
 	gtk_widget_set_sensitive(item, is_dir);
 
 	item = ui_image_menu_item_new(GTK_STOCK_REFRESH, _("Refresh"));
@@ -1211,7 +1233,7 @@ create_popup_menu(gchar *name, gchar *uri)
 
 	item = ui_image_menu_item_new(GTK_STOCK_FIND, _("Find in Files"));
 	gtk_container_add(GTK_CONTAINER(menu), item);
-	g_signal_connect(item, "activate", G_CALLBACK(on_menu_find_in_files), uri);
+	g_signal_connect_data(item, "activate", G_CALLBACK(on_menu_find_in_files), g_strdup(uri), (GClosureNotify)g_free, 0);
 	gtk_widget_set_sensitive(item, is_dir);
 
 	item = gtk_separator_menu_item_new();
@@ -1219,11 +1241,11 @@ create_popup_menu(gchar *name, gchar *uri)
 
 	item = ui_image_menu_item_new(GTK_STOCK_ADD, _("Create new directory"));
 	gtk_container_add(GTK_CONTAINER(menu), item);
-	g_signal_connect(item, "activate", G_CALLBACK(on_menu_create_new_object), "directory");
+	g_signal_connect(item, "activate", G_CALLBACK(on_menu_create_new_object), (gpointer)"directory");
 
 	item = ui_image_menu_item_new(GTK_STOCK_NEW, _("Create new file"));
 	gtk_container_add(GTK_CONTAINER(menu), item);
-	g_signal_connect(item, "activate", G_CALLBACK(on_menu_create_new_object), "file");
+	g_signal_connect(item, "activate", G_CALLBACK(on_menu_create_new_object), (gpointer)"file");
 
 	item = ui_image_menu_item_new(GTK_STOCK_SAVE_AS, _("Rename"));
 	gtk_container_add(GTK_CONTAINER(menu), item);
@@ -1240,17 +1262,17 @@ create_popup_menu(gchar *name, gchar *uri)
 
 	item = ui_image_menu_item_new(GTK_STOCK_CLOSE, g_strdup_printf(_("Close: %s"), name));
 	gtk_container_add(GTK_CONTAINER(menu), item);
-	g_signal_connect(item, "activate", G_CALLBACK(on_menu_close), uri);
+	g_signal_connect_data(item, "activate", G_CALLBACK(on_menu_close), g_strdup(uri), (GClosureNotify)g_free, 0);
 	gtk_widget_set_sensitive(item, is_document);
 
 	item = ui_image_menu_item_new(GTK_STOCK_CLOSE, g_strdup_printf(_("Close Child Documents ")));
 	gtk_container_add(GTK_CONTAINER(menu), item);
-	g_signal_connect(item, "activate", G_CALLBACK(on_menu_close_children), uri);
+	g_signal_connect_data(item, "activate", G_CALLBACK(on_menu_close_children), g_strdup(uri), (GClosureNotify)g_free, 0);
 	gtk_widget_set_sensitive(item, is_dir);
 
 	item = ui_image_menu_item_new(GTK_STOCK_COPY, _("Copy full path to clipboard"));
 	gtk_container_add(GTK_CONTAINER(menu), item);
-	g_signal_connect(item, "activate", G_CALLBACK(on_menu_copy_uri), uri);
+	g_signal_connect_data(item, "activate", G_CALLBACK(on_menu_copy_uri), g_strdup(uri), (GClosureNotify)g_free, 0);
 	gtk_widget_set_sensitive(item, is_exists);
 
 	item = gtk_separator_menu_item_new();
@@ -1294,7 +1316,7 @@ create_popup_menu(gchar *name, gchar *uri)
  * ------------------ */
 
 static void
-on_button_go_up()
+on_button_go_up(void)
 {
 	gchar *uri;
 
@@ -1304,13 +1326,13 @@ on_button_go_up()
 }
 
 static void
-on_button_refresh()
+on_button_refresh(void)
 {
 	treebrowser_chroot(addressbar_last_address);
 }
 
 static void
-on_button_go_home()
+on_button_go_home(void)
 {
 	gchar *uri;
 
@@ -1320,7 +1342,7 @@ on_button_go_home()
 }
 
 static void
-on_button_current_path()
+on_button_current_path(void)
 {
 	gchar *uri;
 
@@ -1330,7 +1352,7 @@ on_button_current_path()
 }
 
 static void
-on_button_hide_bars()
+on_button_hide_bars(void)
 {
 	showbars(FALSE);
 }
@@ -1363,22 +1385,65 @@ on_filter_clear(GtkEntry *entry, gint icon_pos, GdkEvent *event, gpointer data)
 static gboolean
 on_treeview_mouseclick(GtkWidget *widget, GdkEventButton *event, GtkTreeSelection *selection)
 {
-	GtkTreeIter 	iter;
-	GtkTreeModel 	*model;
-	gchar 			*name = "", *uri = "";
-
-	if (gtk_tree_selection_get_selected(selection, &model, &iter))
-		/* FIXME: name and uri should be freed, but they are passed to create_popup_menu()
-		 * that pass them directly to some callbacks, so we can't free them here for now.
-		 * Gotta find a way out... */
-		gtk_tree_model_get(GTK_TREE_MODEL(treestore), &iter,
-							TREEBROWSER_COLUMN_NAME, &name,
-							TREEBROWSER_COLUMN_URI, &uri,
-							-1);
-
 	if (event->button == 3)
 	{
-		gtk_menu_popup(GTK_MENU(create_popup_menu(name, uri)), NULL, NULL, NULL, NULL, event->button, event->time);
+		GtkTreeIter 	iter;
+		GtkTreeModel 	*model;
+		GtkTreePath *path;
+		GtkWidget *menu;
+		gchar *name = NULL, *uri = NULL;
+
+		/* Get tree path for row that was clicked */
+		if (gtk_tree_view_get_path_at_pos(GTK_TREE_VIEW(treeview),
+																		 (gint) event->x,
+																		 (gint) event->y,
+																		 &path, NULL, NULL, NULL))
+		{
+			/* Unselect current selection; select clicked row from path */
+			gtk_tree_selection_unselect_all(selection);
+			gtk_tree_selection_select_path(selection, path);
+			gtk_tree_path_free(path);
+		}
+
+		if (gtk_tree_selection_get_selected(selection, &model, &iter))
+			gtk_tree_model_get(GTK_TREE_MODEL(treestore), &iter,
+								TREEBROWSER_COLUMN_NAME, &name,
+								TREEBROWSER_COLUMN_URI, &uri,
+								-1);
+
+		menu = create_popup_menu(name != NULL ? name : "", uri != NULL ? uri : "");
+		gtk_menu_popup(GTK_MENU(menu), NULL, NULL, NULL, NULL, event->button, event->time);
+
+		g_free(name);
+		g_free(uri);
+		return TRUE;
+	}
+
+	return FALSE;
+}
+
+static gboolean
+on_treeview_keypress(GtkWidget *widget, GdkEventKey *event)
+{
+	if (event->keyval == GDK_space)
+	{
+		GtkTreeIter		iter;
+		GtkTreeModel	*model;
+		GtkTreePath		*path;
+
+		if (gtk_tree_selection_get_selected(gtk_tree_view_get_selection(GTK_TREE_VIEW(widget)), &model, &iter))
+		{
+			path = gtk_tree_model_get_path(model, &iter);
+			if (gtk_tree_view_row_expanded(GTK_TREE_VIEW(widget), path))
+				gtk_tree_view_collapse_row(GTK_TREE_VIEW(widget), path);
+			else
+				gtk_tree_view_expand_row(GTK_TREE_VIEW(widget), path, FALSE);
+			return TRUE;
+		}
+	}
+	if (event->keyval == GDK_BackSpace)
+	{
+		on_button_go_up();
 		return TRUE;
 	}
 
@@ -1492,8 +1557,7 @@ on_treeview_renamed(GtkCellRenderer *renderer, const gchar *path_string, const g
 	GtkTreeViewColumn 	*column;
 	GList 				*renderers;
 	GtkTreeIter 		iter, iter_parent;
-	gchar 				*uri, *uri_new;
-	GtkTreePath 		*path_parent;
+	gchar 				*uri, *uri_new, *dirname;
 
 	column 		= gtk_tree_view_get_column(GTK_TREE_VIEW(treeview), 0);
 	renderers 	= _gtk_cell_layout_get_cells(column);
@@ -1506,30 +1570,32 @@ on_treeview_renamed(GtkCellRenderer *renderer, const gchar *path_string, const g
 		gtk_tree_model_get(GTK_TREE_MODEL(treestore), &iter, TREEBROWSER_COLUMN_URI, &uri, -1);
 		if (uri)
 		{
-			uri_new = g_strconcat(g_path_get_dirname(uri), G_DIR_SEPARATOR_S, name_new, NULL);
+			dirname = g_path_get_dirname(uri);
+			uri_new = g_strconcat(dirname, G_DIR_SEPARATOR_S, name_new, NULL);
+			g_free(dirname);
 			if (!(g_file_test(uri_new, G_FILE_TEST_EXISTS) &&
+				strcmp(uri, uri_new) != 0 &&
 				!dialogs_show_question(_("Target file '%s' exists, do you really want to replace it?"), uri_new)))
 			{
 				if (g_rename(uri, uri_new) == 0)
 				{
+					dirname = g_path_get_dirname(uri_new);
 					gtk_tree_store_set(treestore, &iter,
 									TREEBROWSER_COLUMN_NAME, name_new,
 									TREEBROWSER_COLUMN_URI, uri_new,
 									-1);
-					path_parent = gtk_tree_model_get_path(GTK_TREE_MODEL(treestore), &iter);
-					if (gtk_tree_path_up(path_parent))
-					{
-						if (gtk_tree_model_get_iter(GTK_TREE_MODEL(treestore), &iter_parent, path_parent))
-							treebrowser_browse(g_path_get_dirname(uri_new), &iter_parent);
-						else
-							treebrowser_browse(g_path_get_dirname(uri_new), NULL);
-					}
+					if (gtk_tree_model_iter_parent(GTK_TREE_MODEL(treestore), &iter_parent, &iter))
+						treebrowser_browse(dirname, &iter_parent);
 					else
-						treebrowser_browse(g_path_get_dirname(uri_new), NULL);
+						treebrowser_browse(dirname, NULL);
+					g_free(dirname);
 
 					if (!g_file_test(uri, G_FILE_TEST_IS_DIR))
-						if (document_close(document_find_by_filename(uri)))
+					{
+						GeanyDocument *doc = document_find_by_filename(uri);
+						if (doc && document_close(doc))
 							document_open_file(uri_new, FALSE, NULL, NULL);
+					}
 				}
 			}
 			g_free(uri_new);
@@ -1539,7 +1605,7 @@ on_treeview_renamed(GtkCellRenderer *renderer, const gchar *path_string, const g
 }
 
 static void
-treebrowser_track_current_cb()
+treebrowser_track_current_cb(void)
 {
 	if (CONFIG_FOLLOW_CURRENT_DOC)
 		treebrowser_track_current();
@@ -1559,7 +1625,7 @@ treeview_separator_func(GtkTreeModel *model, GtkTreeIter *iter, gpointer data)
 }
 
 static GtkWidget*
-create_view_and_model()
+create_view_and_model(void)
 {
 
 	GtkWidget 			*view;
@@ -1604,7 +1670,7 @@ create_view_and_model()
 }
 
 static void
-create_sidebar()
+create_sidebar(void)
 {
 	GtkWidget 			*scrollwin;
 	GtkWidget 			*toolbar;
@@ -1687,6 +1753,7 @@ create_sidebar()
 	g_signal_connect(treeview, 			"row-activated", 		G_CALLBACK(on_treeview_row_activated), 			NULL);
 	g_signal_connect(treeview, 			"row-collapsed", 		G_CALLBACK(on_treeview_row_collapsed), 			NULL);
 	g_signal_connect(treeview, 			"row-expanded", 		G_CALLBACK(on_treeview_row_expanded), 			NULL);
+	g_signal_connect(treeview, 			"key-press-event", 		G_CALLBACK(on_treeview_keypress), 			NULL);
 	g_signal_connect(addressbar, 		"activate", 			G_CALLBACK(on_addressbar_activate), 			NULL);
 	g_signal_connect(filter, 			"activate", 			G_CALLBACK(on_filter_activate), 				NULL);
 
@@ -1721,13 +1788,13 @@ static struct
 } configure_widgets;
 
 static void
-load_settings()
+load_settings(void)
 {
 	GKeyFile *config 	= g_key_file_new();
 
 	g_key_file_load_from_file(config, CONFIG_FILE, G_KEY_FILE_NONE, NULL);
 
-	CONFIG_OPEN_EXTERNAL_CMD 		=  utils_get_setting_string(config, "treebrowser", "open_external_cmd", 	CONFIG_OPEN_EXTERNAL_CMD);
+	CONFIG_OPEN_EXTERNAL_CMD 		=  utils_get_setting_string(config, "treebrowser", "open_external_cmd", 	CONFIG_OPEN_EXTERNAL_CMD_DEFAULT);
 	CONFIG_REVERSE_FILTER 			= utils_get_setting_boolean(config, "treebrowser", "reverse_filter", 		CONFIG_REVERSE_FILTER);
 	CONFIG_ONE_CLICK_CHDOC 			= utils_get_setting_boolean(config, "treebrowser", "one_click_chdoc", 		CONFIG_ONE_CLICK_CHDOC);
 	CONFIG_SHOW_HIDDEN_FILES 		= utils_get_setting_boolean(config, "treebrowser", "show_hidden_files", 	CONFIG_SHOW_HIDDEN_FILES);
@@ -1744,7 +1811,7 @@ load_settings()
 }
 
 static gboolean
-save_settings()
+save_settings(void)
 {
 	GKeyFile 	*config 		= g_key_file_new();
 	gchar 		*config_dir 	= g_path_get_dirname(CONFIG_FILE);
@@ -1950,6 +2017,14 @@ static void kb_activate(guint key_id)
 		case KB_RENAME_OBJECT:
 			treebrowser_rename_current();
 			break;
+			
+		case KB_CREATE_FILE:
+			treebrowser_create_new_current("file");
+			break;
+			
+		case KB_CREATE_DIR:
+			treebrowser_create_new_current("directory");
+			break;
 
 		case KB_REFRESH:
 			on_menu_refresh(NULL, NULL);
@@ -1980,6 +2055,10 @@ plugin_init(GeanyData *data)
 		0, 0, "focus_path_entry", _("Focus Path Entry"), NULL);
 	keybindings_set_item(key_group, KB_RENAME_OBJECT, kb_activate,
 		0, 0, "rename_object", _("Rename Object"), NULL);
+	keybindings_set_item(key_group, KB_CREATE_FILE, kb_activate,
+		0, 0, "create_file", _("Create New File"), NULL);
+	keybindings_set_item(key_group, KB_CREATE_DIR, kb_activate,
+		0, 0, "create_dir", _("Create New Directory"), NULL);
 	keybindings_set_item(key_group, KB_REFRESH, kb_activate,
 		0, 0, "rename_refresh", _("Refresh"), NULL);
 
@@ -1988,7 +2067,7 @@ plugin_init(GeanyData *data)
 }
 
 void
-plugin_cleanup()
+plugin_cleanup(void)
 {
 	g_free(addressbar_last_address);
 	g_free(CONFIG_FILE);
