@@ -258,14 +258,14 @@ on_browser_populate_popup (GwhBrowser *browser,
   
   item = gtk_separator_menu_item_new ();
   gtk_widget_show (item);
-  gtk_menu_append (menu, item);
+  gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
   
   g_object_get (G_OBJECT (G_settings), "browser-auto-reload", &auto_reload,
                 NULL);
   item = gtk_check_menu_item_new_with_mnemonic (_("Reload upon document saving"));
   gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (item), auto_reload);
   gtk_widget_show (item);
-  gtk_menu_append (menu, item);
+  gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
   g_signal_connect (item, "toggled", G_CALLBACK (on_item_auto_reload_toggled),
                     NULL);
 }
@@ -338,6 +338,12 @@ load_config (void)
     _("Last geometry of the inspector window"),
     "400x300",
     G_PARAM_READWRITE));
+  gwh_settings_install_property (G_settings, g_param_spec_boolean (
+    "inspector-detached",
+    _("Inspector detached"),
+    _("Whether the inspector is in a separate window or docked in the browser"),
+    FALSE,
+    G_PARAM_READWRITE));
   gwh_settings_install_property (G_settings, g_param_spec_boolean (
     "wm-secondary-windows-skip-taskbar",
     _("Secondary windows skip task bar"),
